<?php

namespace App\Http\Controllers\API;

use App\Models\User;
use App\Models\Order;
use App\Models\Tips;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use App\Http\Controllers\Controller;
use App\Models\Coffee;
use App\Models\SaasSubscription;
use App\Notifications\NewCoffeeNotification;
use App\Notifications\NewOrderNotification;
use App\Notifications\OrderStatusNotification;
use App\Notifications\SaasSubscriberNotification;
use App\Notifications\TipReceivedNotification;

class PayPalController extends Controller
{
    // Saas "Platinum" Subscription IPN Handling
    public function saasIPN(string $plan, int $subscriber, Request $r)
    {
        // STEP 1: read POST data
        $raw_post_data = file_get_contents('php://input');
        $raw_post_array = explode('&', $raw_post_data);

        $myPost = array();

        foreach ($raw_post_array as $keyval) {
            $keyval = explode('=', $keyval);
            if (count($keyval) == 2) {
                $myPost[$keyval[0]] = urldecode($keyval[1]);
            }
        }

        // read the IPN message sent from PayPal and prepend 'cmd=_notify-validate'
        $req = 'cmd=_notify-validate';

        // build req
        foreach ($myPost as $key => $value) {
            $value = urlencode($value);
            $req .= '& ' . trim(strip_tags($key)) . '=' . trim(strip_tags($value));
        }

        // STEP 2: POST IPN data back to PayPal to validate
        $ch = curl_init(config('app.paypal_ipn_url'));
        curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $req);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
        curl_setopt($ch, CURLOPT_FORBID_REUSE, 1);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Connection: Close'));

        // error?
        if (!($res = curl_exec($ch))) {
            curl_close($ch);
            exit;
        } 
        curl_close($ch);

        // STEP 3: Inspect IPN validation result and act accordingly
        if (preg_match("/VERIFIED/i", $res)) {

            // get price that was supposed to be
            $expectedPrice = opt('saas.monthlyPrice');

            if ($plan == 'yearly') {
                $expectedPrice = opt('saas.yearlyPrice');
            }

            // find this user
            $user = User::findOrFail($subscriber);

            switch ($r->txn_type) {
                case 'subscr_signup':

                    // save this order in database
                    $saasSubscription = new SaasSubscription();
                    $saasSubscription->subscr_id = $r->subscr_id;
                    $saasSubscription->user_id = $user->id;
                    $saasSubscription->plan = $plan;
                    $saasSubscription->gateway = 'PayPal';
                    $saasSubscription->subscr_expires = now();
                    $saasSubscription->subscr_status = 'Pending Activation';
                    $saasSubscription->save();

                    break;

                case 'subscr_payment':

                    // get subscription
                    $subscription = SaasSubscription::where('subscr_id', $r->subscr_id)->firstOrFail();

                    // validate amount
                    $price = $r->mc_gross;
                    if ($price != $expectedPrice) {
                        exit;
                    }

                    // compute expires
                    $subscrExpires = now()->addMonths(1);

                    if ($plan == 'yearly') {
                        $subscrExpires = now()->addYears(1);
                    }

                    // update expires and amount
                    $subscription->amount = $price;
                    $subscription->subscr_expires = $subscrExpires;
                    $subscription->subscr_status = 'Active';
                    $subscription->save();

                    // update user plan
                    $user->subscription_expires = $subscrExpires;
                    $user->subscription_id = $subscription->id;
                    $user->subscription_gateway = 'PayPal';
                    $user->save();

                    // notify admin of new platinum saas subscriber
                    try {
                        $admin = User::where('isAdmin', 'yes')->first();
                        $admin->notify(new SaasSubscriberNotification($user, $subscription));
                    } catch (\Exception $e) {
                        Log::error($e->getMessage());
                    }

                    break;

                case 'subscr_cancel':

                    // get subscription
                    $subscription = SaasSubscription::where('subscription_id', $r->subscr_id)->firstOrFail();

                    $subscription->subscr_status = 'Canceled';
                    $subscription->save();

                    break;
            }
        } else {
            $log = '';
            foreach ($_POST as $K => $V) {
                $log .= $K . '=>' . $V . PHP_EOL;
            }
        }
    }

    // Shop Products IPN Handling
    public function shopIPN(Request $r)
    {
        $r->validate(['custom' => 'required|exists:orders,id']);

        // STEP 1: read POST data
        $raw_post_data = file_get_contents('php://input');
        $raw_post_array = explode('&', $raw_post_data);

        $myPost = [];

        foreach ($raw_post_array as $keyval) {
            $keyval = explode('=', $keyval);
            if (count($keyval) == 2) {
                $myPost[$keyval[0]] = urldecode($keyval[1]);
            }
        }

        // read the IPN message sent from PayPal and prepend 'cmd=_notify-validate'
        $req = 'cmd=_notify-validate';

        // build req
        foreach ($myPost as $key => $value) {
            $value = urlencode($value);
            $req .= '& ' . trim(strip_tags($key)) . '=' . trim(strip_tags($value));
        }

        // STEP 2: POST IPN data back to PayPal to validate
        $ch = curl_init(config('app.paypal_ipn_url'));
        curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $req);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
        curl_setopt($ch, CURLOPT_FORBID_REUSE, 1);
        curl_setopt($ch, CURLOPT_HTTPHEADER, ['Connection: Close']);

        // error?
        if (!($res = curl_exec($ch))) {
            Log::info('route(shopIPN)');
            Log::error('Got ' . curl_error($ch) . ' when processing IPN data');
            curl_close($ch);
            exit();
        } else {
            Log::info('IPN_POSTED_SUCCESSFULLY');
        }
        curl_close($ch);


        // STEP 3: Inspect IPN validation result and act accordingly
        if (preg_match('/VERIFIED/i', $res)) {
            // check if payment status is completed
            if ($r->payment_status != 'Completed') {
                exit();
            }

            // find this order
            $order = Order::findOrFail($r->custom);

            switch ($r->txn_type) {
                case 'web_accept':
                    // update order status
                    $order->order_status = __('Paid');
                    $order->save();

                    // increase product sales
                    $order->product->increment('sales');

                    // decrease stock if not null
                    if ($order->product->stock >= 1) {
                        $order->product->decrement('stock');
                    }

                    // notify seller of his new order
                    try {
                        $order->seller->notify(new NewOrderNotification($order));
                        $order->buyer->notify(new OrderStatusNotification($order));
                    } catch (\Exception $e) {
                        \Log::error($e->getMessage());
                    }

                    break;
            }
        } 
    }

    // Koffee IPN
    public function coffeeIPN(Request $r)
    {
        $r->validate(['custom' => 'required|exists:coffees,id']);

        // STEP 1: read POST data
        $raw_post_data = file_get_contents('php://input');
        $raw_post_array = explode('&', $raw_post_data);

        $myPost = [];

        foreach ($raw_post_array as $keyval) {
            $keyval = explode('=', $keyval);
            if (count($keyval) == 2) {
                $myPost[$keyval[0]] = urldecode($keyval[1]);
            }
        }

        // read the IPN message sent from PayPal and prepend 'cmd=_notify-validate'
        $req = 'cmd=_notify-validate';

        // build req
        foreach ($myPost as $key => $value) {
            $value = urlencode($value);
            $req .= '& ' . trim(strip_tags($key)) . '=' . trim(strip_tags($value));
        }

        // STEP 2: POST IPN data back to PayPal to validate
        $ch = curl_init(config('app.paypal_ipn_url'));
        curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $req);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
        curl_setopt($ch, CURLOPT_FORBID_REUSE, 1);
        curl_setopt($ch, CURLOPT_HTTPHEADER, ['Connection: Close']);

        // error?
        if (!($res = curl_exec($ch))) {
            curl_close($ch);
            exit();
        } 
        curl_close($ch);


        // STEP 3: Inspect IPN validation result and act accordingly
        if (preg_match('/VERIFIED/i', $res)) {
            // check if payment status is completed
            if ($r->payment_status != 'Completed') {
                exit();
            }

            // find this coffee
            $order = Coffee::findOrFail($r->custom);

            switch ($r->txn_type) {
                case 'web_accept':
                    // update order status
                    $order->payment_status = 'Paid';
                    $order->save();

                    // notify creator of his new coffee
                    try {
                        $order->seller->notify(new NewCoffeeNotification($order));
                    } catch (\Exception $e) {
                        \Log::error($e->getMessage());
                    }

                    break;
            }
        } 
    }


    // PayPal TIPS IPN
    public function processPayPalTip($creator, $subscriber, $post, Request $r)
    {
        // STEP 1: read POST data
        $raw_post_data = file_get_contents('php://input');
        $raw_post_array = explode('&', $raw_post_data);

        $myPost = array();

        foreach ($raw_post_array as $keyval) {
            $keyval = explode('=', $keyval);
            if (count($keyval) == 2)
                $myPost[$keyval[0]] = urldecode($keyval[1]);
        }

        // read the IPN message sent from PayPal and prepend 'cmd=_notify-validate'
        $req = 'cmd=_notify-validate';

        // build req
        foreach ($myPost as $key => $value) {
            $value = urlencode($value);
            $req .= '& ' . trim(strip_tags($key)) . '=' . trim(strip_tags($value));
        }

        // STEP 2: POST IPN data back to PayPal to validate
        $ch = curl_init(config('app.paypal_ipn_url'));
        curl_setopt($ch, CURLOPT_HTTP_VERSION, CURL_HTTP_VERSION_1_1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $req);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 1);
        curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
        curl_setopt($ch, CURLOPT_FORBID_REUSE, 1);
        curl_setopt($ch, CURLOPT_HTTPHEADER, array('Connection: Close'));

        // error?
        if (!($res = curl_exec($ch))) {
            curl_close($ch);
            exit;
        } 
        curl_close($ch);

        // STEP 3: Inspect IPN validation result and act accordingly
        if (preg_match("/VERIFIED/i", $res)) {

            // find this creator
            $creator = User::findOrFail($creator);

            // find this subscriber
            $subscriber = User::findOrFail($subscriber);

            // compute price
            $price = $r->mc_gross;

            // get platform fee
            $platform_fee = opt('payment-settings.site_fee');
            $fee_amount = ($price * $platform_fee) / 100;

            // compute creator amount
            $creator_amount = number_format($price - $fee_amount, 2);

            switch ($r->txn_type) {

                case 'web_accept':

                    // create tip
                    $tip = new Tips;
                    $tip->tipper_id = $subscriber->id;
                    $tip->creator_id = $creator->id;
                    $tip->post_id = $post;
                    $tip->amount = $r->mc_gross;
                    $tip->gateway = 'PayPal';
                    $tip->payment_status = 'Paid';
                    $tip->save();

                    // notify creator by email and on site
                    $creator->notify(new TipReceivedNotification($tip));

                    break;
            }
        } 
    }
}
