<?php

namespace App\Http\Controllers\API;

use App\Models\User;
use Stripe\Webhook as StripeWebhook;
use Illuminate\Http\Request;
use App\Models\SaasSubscription;
use Illuminate\Support\Facades\Log;
use App\Http\Controllers\Controller;
use App\Models\UserMeta;
use App\Notifications\SaasSubscriberNotification;

class StripeController extends Controller
{
    public function webhooksListener(Request $r)
    {
        try {
            
            $webhookSecret = opt('STRIPE_WEBHOOK_SECRET');

            $event = StripeWebhook::constructEvent(
                $r->getContent(),
                $r->header('stripe-signature'),
                $webhookSecret
            );

            $type = $event['type'];
            $object = $event['data']['object'];

            switch ($type) {
                case 'invoice.paid':

                    // find this user by customer id in user_meta table 
                    $userMeta = UserMeta::where('meta_value', $object->customer)->first();
                    if(!$userMeta) {
                        return response(__('Failed finding customer'));
                    }
                    // fetch user
                    $user = User::find($userMeta->user_id);
                    if(!$user) {
                        return response(__('Failed finding user by user_id'));
                    }


                    // update plan expiration
                    $planExpires = $object->lines->data[0]->period->end;

                    // check plan expires > 1 month
                    $plan = 'monthly';
                    if($planExpires >= strtotime("+11 Months")) {
                        $plan = 'yearly';
                    }

                    // set plan expiration for db
                    $planExpires = date('Y-m-d H:i:s', $planExpires);

                    // create subscription
					$saasSubscription = new SaasSubscription;
                    $saasSubscription->subscr_id = $object->subscription;
                    $saasSubscription->user_id = $user->id;
                    $saasSubscription->plan = $plan;
                    $saasSubscription->gateway = 'Stripe';
                    $saasSubscription->amount = $object->amount_paid/100;
                    $saasSubscription->subscr_expires = $planExpires;
                    $saasSubscription->subscr_status = 'Active';
                    $saasSubscription->save();

                    // update user subscription expires
                    $user->subscription_expires = $planExpires;
                    $user->subscription_gateway = 'Stripe';
                    $user->subscription_id = $saasSubscription->id;
                    $user->save();

                    // notify admin of new platinum saas subscriber
                    try {
                        $admin = User::where('isAdmin', 'yes')->first();
                        $admin->notify(new SaasSubscriberNotification($user, $saasSubscription));
                    }catch(\Exception $e) {
                        Log::error($e->getMessage());
                    }


                break;
                case 'customer.subscription.deleted':
                    
                break;
                default:
                    return response($type . ' not needed');
            }

        }catch(\Exception $e) {
            Log::error($e->getMessage());
        }
    }
}
