<?php

namespace App\Http\Controllers;

use Carbon\Carbon;
use App\Models\Navi;
use App\Models\Page;
use App\Models\Post;
use App\Models\Tips;
use App\Models\User;
use App\Models\Order;
use App\Models\Banned;
use App\Models\Coffee;
use App\Models\Report;
use App\Models\Unlock;
use App\Models\Invoice;
use App\Models\Options;
use App\Models\Product;
use App\Models\Profile;
use App\Models\Category;
use App\Models\Withdraw;
use Illuminate\Support\Str;
use App\Models\ProductImage;
use App\Models\Subscription;
use Illuminate\Http\Request;
use App\Models\SaasSubscription;
use App\Mail\ProfileRejectedMail;
use App\Mail\ProfileVerifiedMail;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;
use App\Mail\PaymentRequestProcessed;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\Storage;
use Stripe\Subscription as StripeSubscription;

class Admin extends Controller
{
    // GET|POST /admin/login
    public function login(Request $r)
    {
        $message = '';

        if ($r->isMethod('post')) {
            $credentials = [
              'email' => request('email'),
              'password' => request('password')
            ];


            if (Auth::attempt($credentials)) {
                // get current user info
                $user = auth()->user();

                if ($user->isAdmin == 'Yes') {
                    return redirect('admin');
                } else {
                    $message = 'Invalid admin login.';
                }
            } else {
                $message = 'Invalid login.';
            }
        }

        return view('admin.admin-login')->with('message', $message);
    }

    // GET /admin/logout
    public function logout()
    {
        \Session::forget('admin');
        auth()->logout();
        return redirect('/admin/login');
    }

    // GET /admin/config-logins
    public function configLogins()
    {
        return view('admin.config-logins')->with('active', 'admin-login');
    }

    // POST /admin/save-logins
    public function saveLogins(Request $r)
    {
        $this->validate($r, [
          'admin_user' => 'required|email',
          'admin_pass' => 'required|confirmed'
        ]);

        $user = auth()->user()->id;
        $user = User::findOrFail($user);

        $user->email = $r->admin_user;
        $user->password = \Hash::make($r->admin_pass);
        $user->save();

        return back()->with('msg', 'Successfully updated admin user details.');
    }

    public function dashboard()
    {
        // get all platinum users
        $platinumUsers = User::where('subscription_expires', '>=', now())->count();

        // get total users
        $allUsers = User::orderBy('id', 'DESC')->count();

        // get start of month
        $startOfMonth = Carbon::now()->startOfMonth();

        // get lifetime subscriptions earnings
        $lifetimeEarnings = SaasSubscription::where('subscr_status', '!=', 'Refunded')
          ->where('subscr_status', '!=', 'Pending Activation')
          ->sum('amount');

        // get subscription earnings since month start
        $subscrMonthEarnings = SaasSubscription::whereBetween('created_at', [$startOfMonth, now()])
          ->where('subscr_status', 'Active')
          ->sum('amount');

        // earnings past 30 days
        $date = \Carbon\Carbon::parse('31 days ago');
        $dateRange = \Carbon\CarbonPeriod::create($date, now());
        $earnings = [];

        foreach ($dateRange as $d) {
            $earnings[$d->format('Y-m-d')] = [
              'date' => $d->format('Y-m-d'),
              'total' => 0,
              'platinumUsers' => 0,
            ];
        }

        // compute subscriptions earnings
        $subscriptionEarnings = SaasSubscription::select(array(
          \DB::raw('DATE(`created_at`) as `date`'),
          \DB::raw('COUNT(`id`) as `platinumUsers`'),
          \DB::raw('SUM(`amount`) as `total`')
        ))
          ->where('created_at', '>', $date)
          ->groupBy('date')
          ->orderBy('date', 'DESC')
          ->get();

        // append subscription earnings
        foreach ($subscriptionEarnings as $d) {
            $earnings[$d->date]['date'] = $d->date;
            $earnings[$d->date]['platinumUsers'] = $d->platinumUsers;
            $earnings[$d->date]['total'] = $d->total;
        }


        // finally, return the view
        return view('admin.dashboard')
          ->with('active', 'dashboard')
          ->with('platinumUsers', $platinumUsers)
          ->with('allUsers', $allUsers)
          ->with('monthEarnings', $subscrMonthEarnings)
          ->with('lifetimeEarnings', $lifetimeEarnings)
          ->with('earnings', $earnings);
    }

    // subscriptions
    public function subscriptions(Request $r)
    {
        if ($r->has('delete')) {
            // get subscription info
            $subscr = Subscription::findOrFail($r->delete);

            // delete
            $subscr->delete();

            return back()->with('msg', 'Subscription deleted.');
        }

        $active = 'subscriptions';
        $subscriptions = Subscription::with('creator', 'subscriber')
          ->orderByDesc('id')
          ->whereDate('subscription_expires', '>=', Carbon::now())
          ->get();
        return view('admin.subscriptions', compact('subscriptions', 'active'));
    }


    // coffees
    public function coffees(Request $r)
    {

        if ($r->has('delete')) {
            // get subscription info
            $coffee = Coffee::findOrFail($r->delete);

            // delete
            $coffee->delete();

            return back()->with('msg', 'Coffee deleted.');
        }

        $active = 'coffees';
        $tips = Coffee::with('buyer', 'seller')
          ->orderByDesc('id')
          ->where('payment_status', 'Paid')
          ->get();


        return view('admin.coffees', compact('tips', 'active'));
    }

    public function editCoffee(Coffee $coffee) {
        $active = 'coffees';

        return view('admin.edit-coffee', compact('coffee'));
    }

    public function updateCoffee(Coffee $coffee, Request $r) {

        $coffee->is_public = $r->isPublic;
        $coffee->message = $r->message;
        $coffee->save();

        return redirect('/admin/coffees')->with('msg', 'Coffee #' . $coffee->id . ' updated.');

    }

    // change visibility of the message
    public function changeCoffeeVisibility($visibility, Coffee $coffee)
    {
        if ($visibility != 'yes' && $visibility != 'no') {
            abort(403, 'Visibility must be yes|no');
        }

        $coffee->is_public = $visibility;
        $coffee->save();

        alert()->info('Coffee message visibility changed');

        return back();
    }

    // products
    public function products()
    {
        $active = 'products';
        $products = Product::with('user')
          ->orderByDesc('id')
          ->get();


        return view('admin.products', compact('products', 'active'));
    }

    // update product
    public function editProduct(Product $product) {
        return view('admin.edit-product', compact('product'));
    }

    public function saveProduct(Product $product, Request $r)
    {
        $r->validate([
          "product_name" => "required|string|max:255",
          "price" => "required",
          "files" => "required|array|min:1",
        ]);

        try {
            DB::beginTransaction();

            // delete existent images (take the new sorting order)
            $prevImages = $product->images()->get();
            $product->images()->delete();
            
            $product->product_name = $r->product_name;
            $product->description = $r->description;
            $product->price = $r->price;
            $product->stock = $r->stock;
            $product->save();

            // save images
            $i = 0;
            foreach ($r->get("files") as $file) {
                if (!$file or empty($file)) {
                    continue;
                }

                // doesn't start with service_pics/ -> take previous
                if (!preg_match("/^product\-pics\//", $file)) {
                    $file = (int) $file;
                    $file = $prevImages
                    ->filter(function ($item) use ($file) {
                        return $item->id == $file;
                    })
                    ->first();

                    if (!$file) {
                        continue;
                    }
                    $file = $file->image;
                } else {
                    $file = $file;
                }

                $image = new ProductImage();
                $image->product_id = $product->id;
                $image->user_id = auth()->id();
                $image->image = $file;
                $image->save();

                if ($i == 0) {
                    $image->is_default = "yes";
                    $image->save();
                }

                $i++;
            }

            DB::commit();

            return back()->with("msg", "Product successfully updated!");

        }catch(\Exception $e) {
            DB::rollBack();
            return back()->with('msg', $e->getMessage());
        }
    }

    // delete product
    public function deleteProduct(Product $product)
    {
        // delete orders related to this product
        Order::where('product_id', $product->id)->delete();
        $product->images()->delete();
        $product->delete();

        return back()->with('msg', 'Product successfully removed');
    }

    // tips
    public function tips(Request $r)
    {

        if ($r->has('delete')) {
            $tip = Tips::findOrFail($r->delete);
            $tip->delete();

            return back()->with('msg', 'User tip successfully removed!');
        }

        $active = 'tips';
        $tips = Tips::with('tipper', 'tipped')
          ->orderByDesc('id')
          ->where('payment_status', 'Paid')
          ->get();


        return view('admin.tips', compact('tips', 'active'));
    }


    public function platinumUsers(Request $r)
    {
        $active = 'users';

        $users =  SaasSubscription::with('user', 'user.profile')->orderByDesc('id')->get();

        return view('admin.platinum-users', compact('active', 'users'));
    }

    public function editPlatinum($plan) {
        $plan = SaasSubscription::findOrFail($plan);
        $planExpires = explode("-", $plan->subscr_expires);
        list($year, $month, $day) = $planExpires;

        $day = explode(" ", $day);
        $day = reset($day);

        return view('admin.edit-platinum', compact('plan', 'year', 'month', 'day'));
    }

    public function updatePlatinum($plan, Request $r)
    {
        $this->validate($r, [
          'mm'      => 'required|numeric',
          'dd'      => 'required|numeric',
          'yy'      => 'required|numeric'
        ]);

        // compute plan expires
        $planExpires = mktime(0, 0, 0, $r->mm, $r->dd, $r->yy);

        // find plan
        $plan = SaasSubscription::findOrFail($plan);
        $user = $plan->user;

        $plan->subscr_expires = date('Y-m-d H:i:s', $planExpires);
        $plan->save();

        // also to the user table
        $user->subscription_expires = $plan->subscr_expires;
        $user->subscription_gateway = 'Admin';
        $user->subscription_id = $plan->id;
        $user->save();

        return redirect('admin/saas-platinum-users')->with('msg', $user->profile->handle . ' plan successfully updated');
    }

    public function removePlatinum(User $user)
    {
        // delete from saas subscriptions table
        SaasSubscription::where('user_id', $user->id)->delete();

        // delete from users table
        $user->subscription_expires = null;
        $user->subscription_gateway = null;
        $user->subscription_id = null;
        $user->save();

        return redirect('/admin/saas-platinum-users')->with('msg', 'User platinum subscription removed!');
    }

    // edit creator subscription
    public function editSubscription(Subscription $subscription) {

        $planExpires = explode("-", $subscription->subscription_expires);
        list($year, $month, $day) = $planExpires;

        $day = explode(" ", $day);
        $day = reset($day);

        return view('admin.edit-subscription', compact('subscription', 'day', 'month', 'year'));
    }

    public function updateSubscription(Subscription $subscription, Request $r)
    {
        $this->validate($r, [
          'mm'      => 'required|numeric',
          'dd'      => 'required|numeric',
          'yy'      => 'required|numeric',
          'price' => 'required|numeric|min:0',
        ]);

        // compute plan expires
        $planExpires = mktime(0, 0, 0, $r->mm, $r->dd, $r->yy);

        $subscription->subscription_expires = date('Y-m-d H:i:s', $planExpires);
        $subscription->subscription_price = $r->price;
        $subscription->save();

        return redirect('admin/subscriptions')->with('msg', $subscription->subscriber->profile->handle . ' subscription to ' . $subscription->creator->profile->handle . ' successfully updated');
    }

    // users overview
    public function users(Request $r)
    {
        $active = 'users';

        if ($r->has('remove')) {
            if ($r->remove == 22) {
                return back()->with('msg', 'Do not delete the main admin user');
            }


            $user = User::where('id', $r->remove)
              ->whereHas('profile')
              ->orderByDesc('id')
              ->withCount([
                'subscribers' => function ($q) {
                    return $q->where('subscription_expires', '>=', now());
                },
                'subscriptions' => function ($q) {
                    return $q->where('subscription_expires', '>=', now());
                }
              ])
              ->firstOrFail();

            if ($user->subscribers_count > 0 or $user->subscriptions_count > 0) {
                return back()->with('msg', 'Users having paid subscribers or active subscriptions cannot be deleted.');
            }

            $user->delete();

            return back()->with('msg', 'Succesfully removed all this user data');
        }

        $users = User::whereHas('profile')->orderByDesc('id')
          ->withCount(['subscribers' => function ($q) {
              return $q->where('subscription_expires', '>=', now());
          }, 'followers'])
          ->get();

        return view('admin.users', compact('active', 'users'));
    }

    // set admin role
    public function setAdminRole(User $user)
    {
        // set as admin
        $user->isAdmin = 'Yes';
        $user->save();

        return back()->with('msg', 'Successfully added ' . $user->email . ' as an admin');
    }

    // remove admin role
    public function unsetAdminRole(User $user)
    {
        // find if there is any other admin remaining.
        $adminsRemaining = User::where('isAdmin', 'Yes')->where('id', '!=', $user->id)->exists();

        if ($adminsRemaining) {
            $user->isAdmin = 'No';
            $user->save();

            $msg = 'Successfully removed admin role of ' . $user->email;
        } else {
            $msg = 'At all points, there must be at least one admin user on this website.';
        }


        return back()->with('msg', $msg);
    }

    // ban user
    public function banUser(User $user)
    {
        if (auth()->id() == $user->id) {
            return back()->with('msg', 'Do not ban yourself');
        }

        $msg = 'Successfully banned ' . $user->email;

        // set as banned
        $user->isBanned = 'Yes';
        $user->save();

        // if ip is null
        if ($user->ip) {
            // add banned ip entry
            $ban = new Banned();
            $ban->ip = $user->ip;
            $ban->save();

            // add ip msg
            $msg .= '. Also banned ip address: ' . $user->ip;
        }

        return back()->with('msg', $msg);
    }

    // remove user ban
    public function unbanUser(User $user)
    {
        // set as banned
        $user->isBanned = 'No';
        $user->save();

        // removed banned ip entry
        $ban = Banned::where('ip', $user->ip)->get();

        if ($ban->count()) {
            foreach ($ban as $b) {
                $b->delete();
            }
        }

        return back()->with('msg', 'Successfully removed ban for ' . $user->email);
    }

    // login as vendor
    public function loginAsVendor($vendorId)
    {
        // get user
        $user = User::findOrFail($vendorId);

        // login
        \Auth::loginUsingId($user->id);

        return redirect(route('feed'));
    }

    // add plan manually
    public function addPlanManually($vendorId)
    {
        // get user
        $user = User::findOrFail($vendorId);

        // get all creators
        // initial query
        $creators = Profile::where('isVerified', 'Yes')
          ->with('category')
          ->withCount('posts', 'followers')
          ->get();

        // active
        $active = 'vendors';

        return view('admin.add-plan-manually', compact('active', 'user', 'creators'));
    }

    public function addPlanManuallyProcess($vendorId, Request $r)
    {
        $this->validate($r, [
          'mm'      => 'required|numeric',
          'dd'      => 'required|numeric',
          'yy'      => 'required|numeric'
        ]);

        // compute plan expires
        $planExpires = mktime(0, 0, 0, $r->mm, $r->dd, $r->yy);

        // find fan
        $user = User::findOrFail($vendorId);

        // add user plan
        $subscription = new SaasSubscription();
        $subscription->subscr_id = uniqid();
        $subscription->user_id = $vendorId;
        $subscription->amount = 0.00;
        $subscription->plan = 'manual';
        $subscription->gateway = 'Admin';
        $subscription->subscr_expires = date('Y-m-d H:i:s', $planExpires);
        $subscription->subscr_status = 'Active';
        $subscription->save();

        // also to the user table
        $user->subscription_expires = $subscription->subscr_expires;
        $user->subscription_gateway = 'Admin';
        $user->subscription_id = $subscription->id;
        $user->save();


        return redirect('admin/users')->with('msg', $user->profile->handle . ' plan successfully updated');
    }

    // edit user profile
    public function editUser(User $user) {

    }

    // save user profile
    public function updateUser(User $user, Request $r) {

    }

    // categories
    public function categories_overview(Request $r)
    {
        // if remove
        if ($removeId = $r->remove) {
            // does this category contain creators?
            $hasCreators = Profile::where('category_id', $removeId)->count();

            if ($hasCreators != 0) {
                return redirect('admin/categories')->with('msg', 'Sorry, this category contains creators. You can only remove categories that have 0 creators using it.');
            }

            // remove from db
            $d = Category::findOrFail($removeId);
            $d->delete();

            return redirect('admin/categories')->with('msg', 'Successfully removed category');
        }


        // if update
        $catname = '';
        $catID = '';
        if ($updateCat = $r->update) {
            // find category
            $c = Category::findOrFail($updateCat);
            $catname = $c->category;
            $catID = $c->id;
        }

        $categories = Category::withCount('profile')->orderBy('category')->get();

        return view('admin.categories')
          ->with('active', 'categories')
          ->with('categories', $categories)
          ->with('catname', $catname)
          ->with('catID', $catID);
    }

    // add category
    public function add_category(Request $r)
    {
        $this->validate($r, ['catname' => 'required']);

        $c = new Category();
        $c->category = $r->catname;
        $c->save();

        return redirect('admin/categories')->with('msg', 'Category successfully created.');
    }

    // update category
    public function update_category(Request $r)
    {
        $this->validate($r, ['catname' => 'required']);

        $c = Category::findOrFail($r->catID);
        $c->category = $r->catname;
        $c->save();

        return redirect('admin/categories')->with('msg', 'Category successfully updated.');
    }

    // pages controller
    public function pages()
    {
        // get existent pages
        $pages = Page::all();

        return view('admin.pages')->with('pages', $pages)
          ->with('active', 'pages');
    }

    // create a page
    public function create_page(Request $r)
    {
        // validate form entries
        $this->validate($r, ['page_title' => 'unique:pages|required']);

        // save page
        $page = new Page();
        $page->page_title = $r->page_title;
        $page->page_slug  = Str::slug($r->page_title);
        $page->page_content = $r->page_content;
        $page->save();

        return redirect()->route('admin-cms')->with('msg', 'Page successfully created');
    }

    // update page
    public function showUpdatePage($page)
    {
        $page = Page::find($page);
        return view('admin.update-page')->with('p', $page)->with('active', 'pages');
    }

    // update page processing
    public function processUpdatePage($page, Request $r)
    {
        $page = Page::find($page);
        $page->page_title = $r->page_title;
        $page->page_content = $r->page_content;
        $page->save();

        return redirect('admin/cms-edit-' . $page->id)->with('msg', 'Page successfully updated.');
    }

    // delete page
    public function deletePage($page)
    {
        $page = Page::find($page);
        $page->delete();
        return redirect()->route('admin-cms')->with('msg', 'Page successfully deleted.');
    }

    // upload image from CMS
    public function uploadImageFromCMS(Request $r)
    {
        $fileName = $r->file('file')->storePublicly('cms-uploads', 'public');

        return response()->json(['location' => asset($fileName)]);
    }


    // appearance setup
    public function appearance()
    {
        return view('admin.appearance')->with('active', 'appearance');
    }

    // payments and pricing setup
    public function paymentsSetup()
    {
        return view('admin.payments-setup')->with('active', 'payments');
    }

    // payments and pricing setup
    public function paymentsSetupProcess()
    {
        $options = request()->except('_token', 'sb_settings');

        // save options
        foreach ($options as $name => $value) {
            if ($name == 'payment-settings_currency_symbol') {
                $name = 'payment-settings.currency_symbol';
            } elseif ($name == 'payment-settings_currency_code') {
                $name = 'payment-settings.currency_code';
            } elseif ($name == 'payment-settings_site_fee') {
                $name = 'payment-settings.site_fee';
            }elseif( $name == 'saas_monthlyPrice') {
                $name = 'saas.monthlyPrice';
            }elseif( $name == 'saas_yearlyPrice' ) {
                $name = 'saas.yearlyPrice';
            } else {
                $name = $name;
            }

            Options::update_option($name, $value);
        }

        return redirect('admin/payments-settings')->with('msg', 'Payments settings successfully saved!');
    }

    // general configuration
    public function configuration()
    {
        return view('admin.configuration')->with('active', 'config');
    }

    // process configuration changes
    public function configurationProcess(Request $r)
    {
        $options = $r->except([
          '_token',
          'sb_settings',
          'admin_current_pass',
          'admin_new_pass',
          'site_favico'
        ]);

        // save options
        foreach ($options as $name => $value) {
            Options::update_option($name, $value);
        }

        // homepage image updated?
        if ($r->hasFile('homepage_header_image')) {
            // validate image
            $this->validate($r, ['homepage_header_image' => 'required|image']);

            // get extension
            $ext = $r->file('homepage_header_image')->getClientOriginalExtension();

            // set destination
            $destinationPath = public_path() . '/images/';

            // compute a random file name
            $fileName = uniqid(rand()) . '.' . $ext;

            // upload
            $r->file('homepage_header_image')->move($destinationPath, $fileName);

            // update option
            Options::update_option('homepage_header_image', '/images/' . $fileName);
        }

        // site logo updated?
        if ($r->hasFile('site_logo')) {
            // validate image
            $this->validate($r, ['site_logo' => 'required|image']);

            // get extension
            $ext = $r->file('site_logo')->getClientOriginalExtension();

            // set destination
            $destinationPath = public_path() . '/images/';

            // set random file name
            $fileName = uniqid(rand()) . '.' . $ext;

            // upload the logo
            $r->file('site_logo')->move($destinationPath, $fileName);

            // update option
            Options::update_option('site_logo', '/images/' . $fileName);
        }

        // favico updated?
        if ($r->hasFile('site_favico')) {
            // validate favicon
            $this->validate($r, ['site_favico' => 'required|image']);

            // get extension
            $ext = $r->file('site_favico')->getClientOriginalExtension();

            // set destination
            $destinationPath = public_path() . '/images/';

            // set random file name
            $fileName = uniqid(rand()) . '.' . $ext;

            // upload the logo
            $r->file('site_favico')->move($destinationPath, $fileName);


            // update option
            Options::update_option('favicon', '/images/' . $fileName);
        }

        return redirect('admin/configuration')->with('msg', 'Configuration settings successfully saved!');
    }

    // extra CSS / JS
    public function extraCSSJS()
    {
        $active = 'cssjs';

        return view('admin.cssjs', compact('active'));
    }


    // save extra css/js
    public function saveExtraCSSJS(Request $r)
    {
        Options::update_option('admin_extra_CSS', $r->admin_extra_CSS);
        Options::update_option('admin_extra_JS', $r->admin_extra_JS);
        Options::update_option('admin_raw_JS', $r->admin_raw_JS);

        return back()->with('msg', 'Successfully updated extra CSS/JS');
    }

    // mail configuration
    public function mailconfiguration()
    {
        return view('admin/mail-configuration', ['active' => 'mailconfig']);
    }

    // update mail configuration
    public function updateMailConfiguration(Request $r)
    {
        try {
            $i = $r->except(['sb_settings', '_token']);

            foreach ($i as $k => $v) {
                $this->__setEnvironmentValue($k, $v);
            }

            $msg = 'Mail Configuration settings successfully saved!';
        } catch (\Exception $e) {
            $msg = $e->getMessage();
        }

        return redirect('admin/mailconfiguration')->with('msg', $msg);
    }

    // mail test
    public function mailtest()
    {
        try {
            $data['message'] = 'This is a test email to check your mail server configuration.';

            $data['intromessage'] = 'Mail Server Configuration';
            $data['url'] = env('APP_URL') . '/admin/mailconfiguration';
            $data['buttonText'] = 'See Mail Configuration';

            $adminEmail = User::where('isAdmin', 'Yes')->first();


            \Mail::send('emails.test-email', ['data' => $data], function ($m) use ($adminEmail, $data) {
                $m->from(MAIL_FROM_ADDRESS);
                $m->to($adminEmail->email);
                $m->subject('Email Configuration Test');
            });

            return redirect('admin/mailconfiguration')->with('msg', 'Mail sent to your server, it is up to them to deliver it now.');
        } catch (\Exception $e) {
            return redirect('admin/mailconfiguration')->with('msg', $e->getMessage());
        }
    }

    // set .env values
    private function __setEnvironmentValue($envKey, $envValue)
    {
        $configFile = base_path('config.inc.php');

        if (!is_writable($configFile)) {
            throw new \Exception('Sorry, ' . $configFile . ' is not writable, you will unfortunately have to add the mail server configuration using the text editor, or make file writable by CHMOD 0755.');
        }

        $str = file_get_contents($configFile);

        $regex = "/define\('" . $envKey . "',\s?'([^']*)'\)/is";
        $str = preg_replace($regex, "define('" . $envKey . "', '" . $envValue . "')", $str);

        $fp = fopen($configFile, 'w');
        $didWrite =  fwrite($fp, $str);
        fclose($fp);

        return $didWrite;
    }


    // show cloud settings page
    public function cloudSettings()
    {
        $active = 'cloud';
        return view('admin.cloud-settings', compact('active'));
    }

    // save cloud settings
    public function saveCloudSettings(Request $r)
    {
        $options = $r->except([
          '_token', 'sb_settings',
        ]);

        // save options
        foreach ($options as $name => $value) {
            Options::update_option($name, $value);
        }

        return back()->with('msg', 'Cloud storage settings successfully saved');
    }

    // content moderation
    public function moderateContent($content_type, Request $r)
    {
        if ($r->has('delete')) {
            // get post
            $id = $r->delete;
            $post = Post::findOrFail($id);

            // delete from disk
            $mediaType = $post->media_type;
            $mediaFile = $post->media_content;

            if ($post->disk != 'backblaze' && !is_null($mediaFile)) {
                Storage::disk($post->disk)->delete($mediaFile);
            }

            $post->comments()->delete();
            $post->delete();

            return back()->with('msg', 'Post successfully removed!');
        }

        $active = 'moderation';
        $reports = Report::orderByDesc('id')->get();

        // get contents
        $contents = Post::where('media_type', $content_type)
          ->orderByDesc('id')
          ->paginate(20);

        // counts
        $imageCounts = Post::where('media_type', 'Image')->count();
        $textCounts = Post::where('media_type', 'None')->count();
        $audioCounts = Post::where('media_type', 'Audio')->count();
        $videoCounts = Post::where('media_type', 'Video')->count();
        $zipCounts = Post::where('media_type', 'ZIP')->count();

        $counts = [
          'image' => $imageCounts,
          'text' => $textCounts,
          'audio' => $audioCounts,
          'video' => $videoCounts,
          'zip' => $zipCounts
        ];

        return view('admin.content-moderation', compact('active', 'reports', 'content_type', 'counts', 'contents'));
    }

    // delete content report
    public function deleteContentReport($id)
    {
        Report::findOrFail($id)->delete();
        return back()->with('msg', 'Report successfully removed.');
    }

    // edit user post
    public function editUserPost(Post $post) {
        $active = 'moderation';
        return view('admin.edit-post', compact('post', 'active'));
    }

    public function saveUserPost(Post $post, Request $r) {

       $r->validate(['text_content' => 'required|min:2']);

       $post->text_content = $r->text_content;
       $post->lock_type = $r->post_type;
       $post->save(); 

       return redirect('/admin/moderation/Image')->with('msg', 'Post #' . $post->id . ' successfully updated.');
    }

    public function deletePostMedia(Post $post) {

        try {
            Storage::disk($post->disk)->delete($post->media_content);
        }catch(\Exception $e) {

        }

        $post->media_type = 'None';
        $post->media_content = null;
        $post->save();

        return back()->with('msg', 'Post media attachment has been removed');
    }

    // configure entry popup
    public function entryPopup()
    {
        $active = 'popup';
        return view('admin.entry-popup', compact('active'));
    }

    // save entry popup settings
    public function entryPopupSave(Request $r)
    {
        $options = request()->except('_token', 'sbPopup');

        // save options
        foreach ($options as $name => $value) {
            Options::update_option($name, $value);
        }

        return back()->with('msg', 'Report successfully removed.');
    }

    // configure PWA
    public function configurePWA()
    {
        $active = 'pwa-config';
        return view('admin.pwa-config', compact('active'));
    }

    // save PWA Configuration
    public function savePWAConfiguration(Request $r)
    {
        // get all files
        $allFiles = $r->file('files');

        if ($allFiles) {
            foreach ($allFiles as $size => $file) {
                // get icon required dimensions
                $dimensions = explode("x", $size);

                // get width
                $width = $dimensions[0];

                // get height
                $height = $dimensions[1];

                // validate the sizes and "image" type
                $this->validate($r, ['files.' . $size => 'image|mimes:png|dimensions:width=' . $width . ',height=' . $height]);

                // store icon
                $fn = md5(uniqid()) . '.' . $file->getClientOriginalExtension();
                $storeIcon = 'images/icons/' . $fn;
                $file->move(base_path('images/icons'), $fn);

                // set db/cache name
                $optName = 'pwa_' . $size;

                // update in db
                Options::update_option($optName, $storeIcon);

                // refresh cache
                Cache::forget($optName);
            }
        }

        // update short name
        Options::update_option('laravel_short_pwa', $r->laravel_short_pwa);

        return back()->with('msg', 'Successfully updated the uploaded items.');
    }
}
