<?php

namespace App\Http\Controllers\Auth;

use App\Http\Controllers\Controller;
use App\Models\User;
use App\Providers\RouteServiceProvider;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Validation\Rules;

class RegisteredUserController extends Controller
{
    /**
     * Display the registration view.
     *
     * @return \Illuminate\View\View
     */
    public function create()
    {
        return view('auth.register');
    }

    /**
     * Handle an incoming registration request.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\RedirectResponse
     *
     * @throws \Illuminate\Validation\ValidationException
     */
    public function store(Request $request)
    {

        $reserved = implode(',', $this->reservedUsernames());

        $request->validate([
            'name' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'confirmed', Rules\Password::defaults()],
            'username' => [
                'required', 'regex:/^[\w-]*$/',
                'unique:creator_profiles,username',
                'not_in:' . $reserved
            ],
        ]);

        $user = User::create([
            'name' => $request->name,
            'email' => $request->email,
            'password' => Hash::make($request->password),
        ]);

        $user->username = $request->username;
        event(new Registered($user));

        Auth::login($user);

        return redirect(RouteServiceProvider::HOME);
    }

        // reserved usernames
    private function reservedUsernames() {

        return [
            'admin',
            'vendor',
            'feed',
            'uploads',
            'notifications',
            'messages',
            'my-profile',
            'browse-creators',
            'logout',
            'login',
            'register',
            'report-content',
            'contact-page',
            'contact',
            'withdrawals',
            'upgrader',
            'tests',
            'svg',
            'storage',
            'routes',
            'resources',
            'public',
            'packages',
            'js',
            'images',
            'hooks',
            'helpers',
            'DOCUMENTATION',
            'database',
            'css',
            'config',
            'bootstrap',
            'app'
        ];
  }

}
