<?php

namespace App\Http\Controllers;

use App\Models\Post;
use App\Models\Tips;
use App\Models\User;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Log;
use App\Http\Controllers\Controller;
use App\Notifications\TipReceivedNotification;

class TipsController extends Controller
{

    // reidrect paypal to post
    public function redirectPayPalToPost($post)
    {
        alert()->success(__('general.thanksForTheTip'));
        return redirect(route('single-post', ['post' => $post]));
    }

    // send tip
    public function processTip(Post $post, Request $r)
    {
        $min = $post->profile->minTip;

        // can user receive tips?
        if(!$post->user->canReceiveTips())
            abort(403, __('User tips/donations limit reached'));

        if (!$min)
            $min = opt('minTipAmount', 1.99);

        $r->validate([
            'tipAmountForPost-' . $post->id => 'required|numeric|min:' . $min,
            ],
            [
                'tipAmountForPost-' . $post->id . '.required' => __('general.tipAmountRequired')
            ]
        );

        // get creator
        $creator_id = $post->user_id;
        $creator = User::findOrFail($creator_id);

        // get tipper
        $tipper = auth()->user();

        // set amount
        $amount = $r->{'tipAmountForPost-' . $post->id};

        // owner of this post == tipper id?
        if ($tipper->id == $creator_id) {
            alert()->warning(__('general.dontTipYourself'));
            return back();
        }

        return $this->sendToPayPal($post, $creator, $tipper, $amount);
        
    }

    // send to paypal
    public function sendToPayPal($post, $creator, $tipper, $amount)
    {
        return view('tips.paypal', compact('post', 'creator', 'tipper', 'amount'));
    }

    // process paypal tip

}
