<?php

namespace App\Notifications;

use App\Mail\NewCoffeeEmail;
use App\Models\Coffee;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class NewCoffeeNotification extends Notification
{
    use Queueable;

    /**
     * Create a new notification instance.
     *
     * @return void
     */
    public $coffee;

    public function __construct(Coffee $coffee)
    {
        $this->coffee = $coffee;
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function via($notifiable)
    {
        return ['mail', 'database'];
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new NewCoffeeEmail($this->coffee, $notifiable))->to($notifiable->email);
    }

    /**
     * Get the array representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function toArray($notifiable)
    {
        return [
            'coffee_count' => $this->coffee->coffees,
            'amount' => opt('payment-settings.currency_symbol') . $this->coffee->amount,
            'message' => $this->coffee->message,
            'username' => $this->coffee->buyer->profile->username,
            'handle' => $this->coffee->buyer->profile->handle
        ];
    }
}
