<?php

namespace App\Notifications;

use App\Mail\NewOrderMail;
use App\Models\Order;
use Illuminate\Bus\Queueable;
use Illuminate\Contracts\Queue\ShouldQueue;
use Illuminate\Notifications\Messages\MailMessage;
use Illuminate\Notifications\Notification;

class NewOrderNotification extends Notification
{
    use Queueable;

    /**
     * Create a new notification instance.
     *
     * @return void
     */
    public $order;
    public $order_contents;

    public function __construct(Order $order)
    {
        $this->order = $order;
        $this->order_contents = ($order->order_contents);
    }

    /**
     * Get the notification's delivery channels.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function via($notifiable)
    {
        return ['mail', 'database'];
    }

    /**
     * Get the mail representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return \Illuminate\Notifications\Messages\MailMessage
     */
    public function toMail($notifiable)
    {
        return (new NewOrderMail($this->order, $this->order_contents, $notifiable))->to($notifiable->email);
    }

    /**
     * Get the array representation of the notification.
     *
     * @param  mixed  $notifiable
     * @return array
     */
    public function toArray($notifiable)
    {
        return [
                'product' => $this->order_contents['product_name'],
                'image' => $this->order_contents['image'],
                'seller_handle' => $this->order_contents['handle'],
                'seller_username' => $this->order_contents['username'], 
                'order_total' => $this->order->order_total,
                'order_date' => $this->order->created_at->format('jS F Y'), 
            ];
    }
}
