<?php

namespace App\Providers;

use Illuminate\Support\ServiceProvider;
use App\Models\Page;
use App\Models\Category;
use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\URL;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     *
     * @return void
     */
    public function register()
    {
        //
    }

    /**
     * Bootstrap any application services.
     *
     * @return void
     */
    public function boot()
    {
        Model::unguard();
        \URL::forceScheme('https');

        // stripe related
        putenv('STRIPE_KEY=' . opt('STRIPE_PUBLIC_KEY'));
        putenv('STRIPE_SECRET=' . opt('STRIPE_SECRET_KEY'));

        // put the env into actions
        putenv('APP_KEY=' . APP_KEY);
        putenv('APP_URL=' . FULL_SITE_URL);
        putenv('FULL_SITE_URL=' . FULL_SITE_URL);
        putenv('SENDING_EMAIL=' . MAIL_FROM_ADDRESS);
        putenv('APP_NAME=' . APP_NAME);
        putenv('APP_DEBUG=' . APP_DEBUG);

        // db env
        putenv('DB_CONNECTION=mysql');
        putenv('DB_PORT=3306');
        putenv('DB_HOST=' . DATABASE_HOST);
        putenv('DB_DATABASE=' . DATABASE_NAME);
        putenv('DB_USERNAME=' . DATABASE_USER);
        putenv('DB_PASSWORD=' . DATABASE_PASS);

        // set default storage
        putenv('DEFAULT_STORAGE=' . opt('default_storage', 'public'));

        /******
        S3 FILE SYSTEMS
         ******/
        // wassabi s3 related
        $currentDisks = $this->app->config['filesystems']['disks'];

        // set wasabi settings from db
        $currentDisks['wasabi']['key'] = opt('WAS_ACCESS_KEY_ID');
        $currentDisks['wasabi']['secret'] = opt('WAS_SECRET_ACCESS_KEY');
        $currentDisks['wasabi']['region'] = opt('WAS_DEFAULT_REGION');
        $currentDisks['wasabi']['bucket'] = opt('WAS_BUCKET');
        $currentDisks['wasabi']['endpoint'] = 'https://s3.' . opt('WAS_DEFAULT_REGION') . '.wasabisys.com';

        // append this disk
        $wasabi = $this->app->config->set('filesystems.disks', $currentDisks);

        // AWS S3 related
        $currentDisks = $this->app->config['filesystems']['disks'];

        // set aws settings from db
        $currentDisks['s3']['key'] = opt('AWS_ACCESS_KEY_ID');
        $currentDisks['s3']['secret'] = opt('AWS_SECRET_ACCESS_KEY');
        $currentDisks['s3']['region'] = opt('AWS_DEFAULT_REGION');
        $currentDisks['s3']['bucket'] = opt('AWS_BUCKET');


        $s3 = $this->app->config->set('filesystems.disks', $currentDisks);


        // DigitalOcean Spaces S3 related
        $currentDisks = $this->app->config['filesystems']['disks'];

        // set do settings from db
        $currentDisks['do']['key'] = opt('DO_ACCESS_KEY');
        $currentDisks['do']['secret'] = opt('DO_SECRET_KEY');
        $currentDisks['do']['endpoint'] = 'https://' . opt('DO_SPACES_REGION') . '.digitaloceanspaces.com';
        $currentDisks['do']['region'] = opt('DO_SPACES_REGION');
        $currentDisks['do']['bucket'] = opt('DO_SPACES_BUCKET');

        $do = $this->app->config->set('filesystems.disks', $currentDisks);

        // pass categories to all views categories
        view()->composer('*', function ($view) {
            // get categories
            $categories = Category::orderBy('category', 'ASC')->get();

            // get pages
            $pages = Page::orderBy('page_title')->get();

            // pass to all views
            $view->with('all_categories', $categories);
            $view->with('all_pages', $pages);
        });
    }
}
