@extends('admin.base')

@section('section_title')
    <strong>{{ __('Platinum Saas Subscribers')  }}</strong>
@endsection

@section('section_body')
    <div class="my-5 bg-stone-200 text-stone-500 font-semibold border-2 border-stone-300 p-3 rounded">
        {{ __('Here you will find an overview of the users who subscribed to your PLATINUM Saas plan via PayPal/Stripe.')  }}
        <br/>
        {{ __('You can also') }} 
        <a href="/admin/users" class="text-indigo-700 hover:underline">{{ __('Gift a Platinum Plan')  }}</a> 
        {{__('to any user you wish by going to the users section and selecting which user to gift a plan to.')  }}
    </div>

    @if ($users->count())
        <table class="text-stone-600 table border-collapse w-full bg-white dataTable">
            <thead>
                <tr>
                    <x-th>{{ __('ID')  }}</x-th>
                    <x-th>{{ __('Name')  }}</x-th>
                    <x-th>{{ __('Email')  }}</x-th>
                    <x-th>{{ __('Handle')  }}</x-th>
                    <x-th>{{ __('Gateway')  }}</x-th>
                    <x-th>{{ __('Plan Expires')  }}</x-th>
                    <x-th>{{ __('Action')  }}</x-th>
                </tr>
            </thead>
            <tbody>
                @foreach ($users as $u)
                    <tr>
                        <x-td>
                            <x-slot name="field">{{ __('ID')  }}</x-slot>
                            {{ $u->id }}
                        </x-td>
                        <x-td>
                            <x-slot name="field">{{ __('Name')  }}</x-slot>
                            {{ $u->user->name }}
                        </x-td>
                        <x-td>
                            <x-slot name="field">{{ __('Email')  }}</x-slot>
                            {{ $u->user->email }}
                        </x-td>
                        <x-td>
                            <x-slot name="field">{{ __('Handle')  }}</x-slot>
                            <a href="{{ route('profile.show', ['username' => $u->user->profile->username]) }}"
                                class="text-indigo-600 hover:text-indigo-700" target="_blank">{{ $u->user->profile->handle }}</a>
                        </x-td>
                        <x-td>
                            <x-slot name="field">{{ __('Gateway')  }}</x-slot>
                            <span
                                class="inline-flex px-2 py-1 rounded-lg text-white {{ $u->gateway == 'Stripe' ? 'bg-sky-500' : 'bg-orange-500' }}">
                                {{ $u->gateway }}
                            </span>
                        </x-td>
                        <x-td>
                            <x-slot name="field">{{ __('Plan Expires') }}</x-slot>
                            {{ date('jS F Y', strtotime($u->subscr_expires)) }}
                        </x-td>
                        <x-td>
                            <x-slot name="field">{{ __('Actions') }}</x-slot>
                            <a href="/admin/edit-platinum/{{ $u->id  }}">
                                <i class="fa-solid fa-pencil mr-2 text-teal-600"></i>
                            </a>
                            <a href="/admin/remove-platinum/{{ $u->user->id }}"
                                onclick="return confirm('{{ __('Are you sure you want to delete this user subscription?')  }}')"
                                class="text-red-400 hover:underline">
                                <i class="fa-solid fa-trash"></i>
                            </a>
                        </x-td>
                    </tr>
                @endforeach
            </tbody>
        </table>
    @else
        <div class="p-3 rounded bg-white">{{ __("You don't have any platinum subscribers at the moment")  }}</div>
    @endif
@endsection

@section('extra_bottom')
    @if (count($errors) > 0)
        <div class="alert alert-danger">
            <ul>
                @foreach ($errors->all() as $error)
                    <li>{{ $error }}</li>
                @endforeach
            </ul>
        </div>
    @endif
@endsection

@push('adminExtraJS')
    <script src="{{ asset('js/jquery.min.js') }}"></script>
    <script src="{{ asset('js/datatables/datatables.min.js') }}"></script>
    {{-- attention, dynamic because only needed on this page to save resources  --}}
    <script>
    $('.dataTable').dataTable({ordering:false});
    </script>
@endpush
