@extends('admin.base')

@section('section_title')
    <strong>{{ __('Users Subscribed to Creators')  }}</strong>
@endsection

@section('section_body')

    <div class="my-5 bg-stone-200 text-stone-500 font-semibold border-2 border-stone-300 p-3 rounded">
        {{ __('Here you will find an overview of the paid memberships that creators sold to their fans.')  }}
        <br/>
        {{ __('Wanted to view')  }} 
        <a href="/admin/saas-platinum-users" class="text-indigo-700 hover:underline">
            {{ __('PLATINUM')  }}
        </a> 
        {{ __('subscriptions to your own platform?')  }}
    </div>

    @if (!count($subscriptions))
        <div class="p-3 rounded bg-white">{{ __('No users have subscribed to any of the creators yet. ')  }}</div>
    @else
        <table class="table border-collapse w-full bg-white text-stone-600 dataTable">
            <thead>
                <tr>
                    <x-th>{{ __('ID')  }}</x-th>
                    <x-th>{{ __('Subscriber')  }}</x-th>
                    <x-th>{{ __('Creator')  }}</x-th>
                    <x-th>{{ __('Started')  }}</x-th>
                    <x-th>{{ __('Expires')  }}</x-th>
                    <x-th>{{ __('Price')  }}</x-th>
                    <x-th>{{ __('Actions')  }}</x-th>
                </tr>
            </thead>
            <tbody>
                @forelse ($subscriptions as $t)
                    @if (is_null($t->creator) or is_null($t->subscriber))
                    @else
                        <tr>
                            <x-td>
                                <x-slot name="field">{{ __('ID')  }}</x-slot>
                                {{ $t->id }}
                            </x-td>
                            <x-td>
                                <x-slot name="field">{{ __('Subscriber')  }}</x-slot>
                                {{ $t->subscriber->name }}
                                <br>
                                <a href="/{{ $t->subscriber->profile->username }}">
                                    {{ $t->subscriber->profile->handle }}
                                </a>
                            </x-td>
                            <x-td>
                                <x-slot name="field">{{ __('Creator')  }}</x-slot>
                                {{ $t->creator->name }}
                                <br>
                                <a href="/{{ $t->creator->profile->username }}">
                                    {{ $t->creator->profile->handle }}
                                </a>
                            </x-td>
                            <x-td>
                                <x-slot name="field">{{ __('Date Subscribed')  }}</x-slot>
                                {{ $t->subscription_date->format('jS F Y') }}
                            </x-td>
                            <x-td>
                                <x-slot name="field">{{ __('Expires')  }}</x-slot>
                                {{ $t->subscription_expires->format('jS F Y') }}
                            </x-td>
                            <x-td>
                                <x-slot name="field">{{ __('Price')  }}</x-slot>
                                <span class="inline-flex px-2 py-1 bg-indigo-50 text-indigo-700 rounded-lg">
                                    {{ opt('payment-settings.currency_symbol') . $t->subscription_price }}
                                </span>
                            </x-td>
                            <x-td>
                                <x-slot name="field">{{ __('Actions')  }}</x-slot>
                                <a href="/admin/edit-subscription/{{$t->id}}">
                                    <i class="fa-solid fa-pencil mr-2 text-teal-600"></i>
                                </a>
                                <a href="/admin/subscriptions?delete={{$t->id}}" class="text-red-400 hover:underline" onclick="return confirm('{{ __('Are you sure you want to delete this subscription?')  }}')">
                                    <i class="fa-solid fa-trash"></i>
                                </a>
                            </x-td>
                        </tr>
                    @endif
                @empty
                    {{ __('No users have subscribed to any creators')  }}
                @endforelse
            </tbody>
        </table>
    @endif
@endsection

@section('extra_bottom')
    @if (count($errors) > 0)
        <div class="alert alert-danger">
            <ul>
                @foreach ($errors->all() as $error)
                    <li>{{ $error }}</li>
                @endforeach
            </ul>
        </div>
    @endif
@endsection

@push('adminExtraJS')
    <script src="{{ asset('js/jquery.min.js') }}"></script>
    <script src="{{ asset('js/datatables/datatables.min.js') }}"></script>
    {{-- attention, dynamic because only needed on this page to save resources  --}}
    <script>
    $('.dataTable').dataTable({ordering:false});
    </script>
@endpush
