@extends('admin.base')

@section('section_title')
    <strong>{{ __('Users Management')  }}</strong>
@endsection

@section('section_body')
    <table class="text-stone-600 table border-collapse w-full bg-white dataTable">
        <thead>
            <tr>
                <x-th>{{ __('ID')  }}</x-th>
                <x-th>{{ __('Name')  }}</x-th>
                <x-th>{{ __('Email')  }}</x-th>
                <x-th>{{ __('Followers')  }}</x-th>
                <x-th>{{ __('Subscribers')  }}</x-th>
                <x-th>{{ __('Plan')  }}</x-th>
                <x-th>{{ __('Is Admin')  }}</x-th>
                <x-th>{{ __('IP Address')  }}</x-th>
                <x-th>{{ __('Join Date')  }}</x-th>
                <x-th>{{ __('Actions')  }}</x-th>
            </tr>
        </thead>
        <tbody>
            @foreach ($users as $u)
                <tr>
                    <x-td>
                        <x-slot name="field">{{ __('ID')  }}</x-slot>
                        {{ $u->id }}
                    </x-td>
                    <x-td>
                        <x-slot name="field">{{ __('Name')  }}</x-slot>
                        {{ $u->name }}
                    </x-td>
                    <x-td>
                        <x-slot name="field">{{ __('Email')  }}</x-slot>
                        {{ $u->email }}
                    </x-td>
                    <x-td>
                        <x-slot name="field">{{ __('Followers')  }}</x-slot>
                        {{ $u->followers_count }}
                    </x-td>
                    <x-td>
                        <x-slot name="field">{{ __('Subscribers')  }}</x-slot>
                        {{ $u->subscribers_count }}
                    </x-td>
                    <x-td>
                        <x-slot name="field">{{ __('Plan')  }}</x-slot>
                        @if ($u->isPlatinum())
                            <span class="inline-flex px-2 py-1 bg-indigo-200 text-indigo-700 rounded-lg">
                                {{ __('Platinum')  }}
                            </span>
                        @else
                            <span class="inline-flex px-2 py-1 bg-stone-200 text-stone-700 rounded-lg">
                                {{ __('Free')  }}
                            </span>
                        @endif
                    </x-td>
                    <x-td>
                        <x-slot name="field">{{ __('Is Admin') }}</x-slot>
                        <span
                            class="inline-flex px-2 py-1 rounded-lg text-white {{ $u->isAdmin == 'Yes' ? 'bg-teal-600' : 'bg-stone-500' }}">
                            {{ $u->isAdmin }}
                        </span>
                        <br>
                        @if ($u->isAdmin == 'Yes')
                            <a href="/admin/users/unsetadmin/{{ $u->id }}" class="text-red-400 hover:underline">{{ __('Unset Admin Role')  }}</a>
                        @elseif($u->isAdmin == 'No')
                            <a href="/admin/users/setadmin/{{ $u->id }}" class="text-teal-600 hover:underline">{{ __('Set Admin Role')  }}</a>
                        @endif
                    </x-td>
                    <x-td>
                        <x-slot name="field">{{ __('IP') }}</x-slot>
                        <span class="inline-flex px-2 py-1 bg-slate-100 text-slate-500 rounded-lg">
                            {{ $u->ip ? $u->ip : __('N/A') }}
                        </span>
                        <br>

                        @if ($u->isBanned == 'No')
                            <a href="/admin/users/ban/{{ $u->id }}" class="text-stone-600 hover:underline">
                                {{ __('Ban')  }}
                            </a>
                        @elseif($u->isBanned == 'Yes')
                            <a href="/admin/users/unban/{{ $u->id }}" class="text-red-400 hover:underline">
                                {{ __('Unban')  }}
                            </a>
                        @endif
                    </x-td>
                    <x-td>
                        <x-slot name="field">{{ __('Join Date') }}</x-slot>
                        {{ $u->created_at->format('jS F Y') }}
                    </x-td>
                    <x-td>
                        <x-slot name="field">{{ __('Add Platinum') }}</x-slot>
                        @if($u->isPlatinum())
                            <a href="/admin/edit-platinum/{{ $u->subscription_id  }}" class="text-indigo-700 hover:underline">
                                {{ __('Edit Plan') }}
                            </a>
                            <br/>
                        @else
                        <a href="/admin/add-plan/{{ $u->id }}" class="text-indigo-700 hover:underline">
                            {{ __('Gift Platinum') }}
                        </a>
                        <br>
                        @endif

                        <a href="/admin/loginAs/{{ $u->id }}"
                            onclick="return confirm('{{ __('This will log you out as an admin and login as a vendor. Continue?')  }}')"
                            class="text-teal-600 hover:underline">{{ __('Login as User')  }}</a>

                        <br>
                        <br>
                        <a href="/admin/users?remove={{ $u->id }}"
                            onclick="return confirm('Are you sure you want to delete this user and his data? This is irreversible!!!')"
                            class="text-red-400 hover:underline">{{ __('Delete User & His Data')  }}</a>
                    </x-td>
                </tr>
            @endforeach
        </tbody>
    </table>
@endsection

@section('extra_bottom')
    @if (count($errors) > 0)
        <div class="alert alert-danger">
            <ul>
                @foreach ($errors->all() as $error)
                    <li>{{ $error }}</li>
                @endforeach
            </ul>
        </div>
    @endif
@endsection

@push('adminExtraJS')
    <script src="{{ asset('js/jquery.min.js') }}"></script>
    <script src="{{ asset('js/datatables/datatables.min.js') }}"></script>
    {{-- attention, dynamic because only needed on this page to save resources  --}}
    <script>
    $(document).ready(function() {
        $('.dataTable').dataTable({ordering:false});
    });
    </script>
@endpush
