@extends('welcome')

@section('seo_title') {{ __('Checkout Review')  }} @endsection

@section('content')
<div class="mt-10 mx-auto w-full lg:max-w-lg">

  <h3 class="w-full flex justify-center pt-10 text-3xl text-indigo-800 heading-gradient font-black">
    {{ __('Checkout')  }}
  </h3>

  <h3 class="w-full flex justify-center text-xl text-indigo-800 heading-gradient font-normal">
    {{ __('Chosen amount: ') . opt('payment-settings.currency_symbol') . $amount  }}
  </h3>

  <div class="w-full bg-white rounded-lg shadow-sm p-5 border-indigo-100 text-stone-600 text-lg mt-5 text-justify font-semibold">

    <h3 class="text-xl text-stone-500 font-semibold">{{ __('Order Summary')  }}</h3>

    <div class="mt-2 flex space-x-2 p-2 border border-stone-100 rounded-lg shadow-sm">
      <div>
        <a href="{{$product->slug}}">
          <img src="{{ asset($product->mainImage()) }}" alt="" class="w-24 rounded-lg" />
        </a>
      </div>
      <div>
        <a href="{{$product->slug}}" class="text-stone-500 hover:text-stone-600">
          {{ $product->product_name }}
        </a>
        <br />
        @if($product->is_digital != 'yes')
        <span class="text-stone-500 text-sm">
          {{ __('Shipping Cost: ')  }}
          <span class="shippingCost text-indigo-700">
            {{ $shippingCost }}
          </span>
        </span>
        <br />
        @else
        <span class="text-sm shippingCost text-indigo-700">
          @lang('v104.instantDelivery')
        </span>
        <br />
        @endif
        <span class="text-stone-500 text-sm">
          {{ __('Product sold by ') }}
          <a href="{{route('profile.show', ['username' => $product->user->profile->username ])  }}" class="text-indigo-700 hover:text-indigo-600">{{ $product->user->profile->handle}}</a>
        </span>
      </div>
    </div>

    @if($product->is_digital != 'yes')
    <h3 class="text-xl text-stone-500 font-semibold pb-2 mt-5">{{ __('Shipping Details')  }}</h3>
    @endif

    <form method="POST" name="checkoutFrm" id="checkoutFrm" action="{{route('checkout.processOrder')  }}">
      @csrf
      <input type="hidden" name="gateway" value="paypal">
      <input type="hidden" name="product" value="{{ $product->id }}">
      <input type="hidden" name="price" value="{{ $amount }}">

      @if($product->is_digital != 'yes')
      <x-label>{{ __('Full Name') }}</x-label>
      <x-input class="w-full" name="fullname" value="{{ auth()->check() ? auth()->user()->name : old('fullname') }}" placeholder="{{  __('Full Name')  }}" required />

      <x-label class="mt-3">{{ __('Your Country')  }}</x-label>
      <x-select name="country" id="country" class="w-full">
        @foreach ($shippableCountries as $c)
        <option value="{{ $c }}">{{ $c }}</option>
        @endforeach
      </x-select>

      <div class="lg:flex lg:items-center lg:space-x-2 mt-3">
        <div>
          <x-label>{{ __('City') }}</x-label>
          <x-input class="w-full" name="city" value="{{ old('city') }}" placeholder="{{ __('City')  }}" required />
        </div>

        <div>
          <x-label>{{ __('State') }}</x-label>
          <x-input class="w-full" name="state" value="{{ old('state') }}" placeholder="{{ __('State')  }}" required />
        </div>
      </div>

      <div class="lg:flex lg:items-center lg:space-x-2 mt-3">
        <div>
          <x-label>{{ __('Postcode') }}</x-label>
          <x-input class="w-full" name="postcode" value="{{ old('postcode') }}" placeholder="{{ __('Postcode')  }}" required />
        </div>

        <div>
          <x-label>{{ __('Phone') }}</x-label>
          <x-input class="w-full" name="phone" value="{{ old('phone') }}" placeholder="{{ __('Phone')  }}" />
        </div>
      </div>

      <x-label class="mt-3">{{ __('Address') }}</x-label>
      <x-input class="w-full" name="address" value="{{ old('address') }}" placeholder="{{ __('Address')  }}" required />
      @endif

      <div class="text-center mt-5">
        <x-button>{{ __('Continue to PayPal')  }}</x-button>
      </div>

    </form>
  </div>
</div>
@endsection

{{-- attention, this is dynamically appended as not needed on all pages, using laravel push/stack feature --}}
@push('extraJS')

@if($product->is_digital != 'yes')
<script>
  window.addEventListener('DOMContentLoaded', (event) => {

    $("#checkoutFrm").on('submit', function(e) {
      if ($("#country").val() == "{{ __('Select Country') }}") {
        e.preventDefault();
        Swal.fire({
          title: '{{ __("Select a shipping country!") }}',
          icon: 'error'
        });
      }
    });

    $("#country").on('change', function(e) {
      var countryName = e.target.value;

      if (countryName == "{{ __('Select Country') }}") {
        $('.shippingCost').html("--");
      } else {
        $.get('{{ route("checkout.getShippingPrice") }}?user={{ $product->user_id }}&country=' + countryName, function(resp) {
          $('.shippingCost').html("{{opt('payment-settings.currency_symbol')}}" + resp.price);
        });
      }
    });
  });

  @endif
</script>
@endpush
