@extends('account')

@section('seo_title')
    @lang('dashboard.inbox') -
@endsection

@section('account_section')
    <h2 class="text-2xl text-indigo-800 font-semibold flex items-center">
        <i class="fa-solid fa-envelope mr-2"></i>
        @lang('messages.messages')
    </h2>
    <div class="flex items-center justify-between">
        <div>
            <a href="{{ route('messages.inbox') }}"
                class="text-stone-600 hover:text-stone-500 underline">{{ __('messages.inbox') }}</a> /
            <a href="{{ route('messages.outbox') }}" class="text-stone-600 hover:text-stone-500">{{ __('messages.outbox') }}</a>
        </div>
        <div>
            <a href="{{route('messages.compose') }}" class="text-stone-600 underline hover:no-underline">@lang('messages.compose')</a>
        </div>
    </div>

    @if($messages->count())
    <table class="mt-5 bg-white shadow-sm rounded-lg px-3 py-5 border-collapse table-auto w-full">
        <thead class="bg-indigo-200 rounded-lg">
            <tr>
                <th class="w-20 border-b font-medium py-4 px-2 text-indigo-700 text-left rounded-tl-lg">
                    {{ __('From') }}
                </th>
                <th class="border-b font-medium py-4 px-2 text-indigo-700 text-left">
                    {{ __('Message') }}
                </th>
                <th class="border-b font-medium py-4 px-2 text-indigo-700 text-left">
                    {{ __('Date') }}
                </th>
            </tr>
        </thead>
        <tbody>
            @foreach ($messages as $m)
                <tr class="@if ($m->is_read == 'No') bg-indigo-50 @endif">
                    <td class="py-4 px-2">
                        <div class="flex items-center flex-col">
                            <div class="border-2 border-white bg-white  shadow rounded-full w-14 h-14">
                                <img src="{{ secure_image($m->sender->profile->profilePic, 95, 95) }}"
                                    class="w-full rounded-full" />
                            </div>
                            <a href="{{ route('profile.show', ['username' => $m->sender->profile->username]) }}"
                                target="_blank"
                                class="mt-2 text-blue-500 hover:underline hover:text-blue:600 text-xs font-semibold">
                                {{ $m->sender->profile->handle }}
                            </a>
                        </div>
                    </td>
                    <td class="py-4 px-2">
                        @if ($m->is_read == 'No')
                            <span
                                class="rounded-lg px-2 py-1 bg-indigo-200 font-semibold text-xs text-indigo-700">@lang('messages.unread')</span><br />
                        @endif
                        <span class="text-sm text-stone-500 @if ($m->is_read == 'No') font-semibold @endif">
                            {{ substr($m->message, 0, 120) . (strlen($m->message) > 120 ? '...' : '') }}
                        </span>
                        <a href="{{ route('messages.read', ['message' => $m]) }}"
                            class="flex text-sm text-blue-500 hover:underline hover:text-blue-600">
                            {{ __('Read message') }}
                        </a>
                    </td>
                    <td class="text-stone-500 px-2 py-4 text-sm font-semibold">
                        {{ $m->created_at->diffForHumans() }}
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table>
    @else
    <div class="p-3 rounded-lg text-stone-600 bg-white mt-3">
        @lang('general.noMessages')
    </div>
    @endif

    @if ($messages->hasPages())
        <div class="bg-white rounded-lg shadow-sm px-5 py-8 mt-5">
            {{ $messages->links() }}
        </div>
    @endif
    </div>
@endsection
