<div class="mb-7" data-post-id="{{ $post->id }}">
    <div class="flex items-center justify-between">

        <div class="flex items-center mb-2">
            <div class="border-2 border-white bg-white shadow rounded-full w-16 h-16 z-10 relative">
                <a href="{{ route('profile.show', ['username' => $post->profile->username]) }}">
                    <img src="{{ secure_image($post->profile->profilePic, 95, 95) }}" class="w-full rounded-full" />
                </a>
            </div>
            <div class="pl-2 relative">
                <div class="flex items-center space-x-1">
                    <a href="{{ $post->profile->url }}"
                        class="text-indigo-800 hover:text-indigo-600 font-semibold text-lg">
                        {{ $post->profile->username }}
                    </a>
                    @if ($post->user->isPlatinum())
                        <img src="{{ asset('images/verified-badge.svg') }}" alt="" class="w-4 h-4" />
                    @endif
                </div>
                <div class="text-gray-700 text-sm">
                    {{ $post->created_at->diffForHumans() }}
                </div>
            </div>
        </div>

        <div>
            <x-dropdown>
                <x-slot name="trigger">
                    <span class="text-stone-500 font-black cursor-pointer">...</span>
                </x-slot>
                <x-slot name="content">
                    @if ($post->isCreator())
                        <x-dropdown-link href="{{ route('deletePost', ['post' => $post]) }}" class="delete-post"
                            data-id="{{ $post->id }}">
                            @lang('post.deletePost')
                        </x-dropdown-link>
                    @endif
                    <x-dropdown-link href="javascript:void(0);" data-clipboard-text="{{ $post->slug }}"
                        class="copyLink">
                        @lang('post.copyLink')
                    </x-dropdown-link>
                    <x-dropdown-link href="{{ $post->slug }}">
                        @lang('post.postLink')
                    </x-dropdown-link>
                </x-slot>
            </x-dropdown>
        </div>
    </div>

    <div class="bg-white rounded-lg shadow-sm">

        @if ($post->userHasAccess())

            @include('posts.post-media', ['post' => $post])

            <div class="text-stone-700 mt-3 p-3 break-all">
                {!! clean(turnLinksIntoAtags(nl2br($post->text_content)), 'youtube') !!}
            </div>

            <div class="border-top px-3 py-3">

                <div class="flex items-center border-t pt-2">
                    {{-- likes button starts --}}
                    <a href="@if (auth()->check()) javascript:void(0); @else {{ route('login') }} @endif"
                        class="text-danger noHover @if (auth()->check()) lovePost @endif @if (auth()->check() &&
                            auth()->user()->hasLiked($post)) hidden @endif"
                        data-id="{{ $post->id }}">
                        <img src="{{ asset('images/heart-icon.png') }}" alt="heart-icon" class="w-5" />
                    </a>
                    <a href="javascript:void(0);"
                        class="text-danger noHover unlovePost @if (auth()->check() &&
                            !auth()->user()->hasLiked($post) or !auth()->check()) hidden @endif"
                        data-id="{{ $post->id }}">
                        <img src="{{ asset('images/heart-icon.png') }}" alt="heart-icon" class="w-5" />
                    </a>
                    <span class="post-likes-count text-stone-500 font-bold text-sm ml-1"
                        data-id="{{ $post->id }}">{{ $post->likers_count }}</span>
                    {{-- likes button ends --}}

                    {{-- comments button --}}
                    <a href="@if (auth()->check()) javascript:void(0); @else {{ route('login') }} @endif"
                        class="@if (auth()->check()) loadComments @endif ml-2"
                        data-id="{{ $post->id }}">
                        <img src="{{ asset('images/comments-icon.png') }}" alt="comments-icon" class="w-5" />
                    </a>
                    <span class="post-comments-count text-stone-500 font-bold text-sm ml-1"
                        data-id="{{ $post->id }}">{{ $post->comments->count() }}</span>

                    @if ($post->profile->minTip )
                        <a href="@if (auth()->check()) javascript:void(0); @else {{ route('login') }} @endif"
                            class="@if (auth()->check()) sendTip @endif ml-2"
                            data-post="{{ $post->id }}">
                            <img src="{{ asset('images/tip-icon.png') }}" alt="tip icon" class="w-6" />
                        </a>
                        <a href="@if (auth()->check()) javascript:void(0); @else {{ route('login') }} @endif"
                            class="ml-1 @if (auth()->check()) sendTip @endif text-stone-500 font-bold text-sm"
                            data-post="{{ $post->id }}">
                            @lang('general.tip')
                        </a>
                    @endif 
                </div>

                @include('tips.tip-form', ['post' => $post])

                <div class="leave-comment mt-3 mb-2 hidden" data-id="{{ $post->id }}">

                    <input type="text" name="new-comment-{{ $post->id }}"
                        class="w-full rounded bg-stone-100 text-stone-500 font-semibold text-sm px-1 py-2 leave-comment-inp focus:ring-0 focus:border-transparent"
                        placeholder="@lang('post.writeCommentAndPressEnter')" required="required" data-id="{{ $post->id }}">

                </div>

                <div class="post-{{ $post->id }}-lastId hidden"></div>

                <div class="appendComments hidden" data-id="{{ $post->id }}"></div>

                @if ($post->comments->count() > opt('commentsPerPost', 5))
                    <a class="loadMoreComments hidden" href="javascript:void(0);" data-id="{{ $post->id }}">
                        @lang('post.loadMoreComments')
                    </a>

                    <div class="noMoreComments hidden text-secondary" data-id="{{ $post->id }}">
                        <i class="fas fa-exclamation-triangle"></i> @lang('post.noMoreComments')
                    </div>
                @endif

            </div>
        @else
            {{-- if Post is Paid but current auth() user is not subscribed --}}

            <div class="pt-3 pb-2 pl-3 break-all text-stone-700">
                @if ($post->media_type != 'None')
                    {!! clean($post->text_content) !!}
                @endif
            </div>

            <div class="locked-post p-5 text-center text-stone-400">
                <br><br>

                <h1 class="text-2xl">
                    @if ($post->media_type == 'None')
                        <i class="fas fa-align-left"></i>
                    @elseif($post->media_type == 'Image')
                        <i class="fas fa-image text-5xl"></i>
                    @elseif($post->media_type == 'Video')
                        <i class="fas fa-video"></i>
                    @elseif($post->media_type == 'Audio')
                        <i class="fas fa-music"></i>
                    @elseif($post->media_type == 'ZIP')
                        <i class="fas fa-file-archive"></i>
                    @endif
                </h1>

                <i class="fa fa-lock"></i> @lang('post.locked')

                <br><br><br>
            </div>

            @if ($post->profile->monthlyFee && $post->profile->minTip)
                <div class="ml-2 p-2">
                    @include('tips.tip-form')
                </div>
            @endif

        @endif

        
        @if ($post->profile->minTip && !$post->userHasAccess() )
            <div class="ml-2 flex items-center mb-2">
                <a href="@if (auth()->check()) javascript:void(0); @else {{ route('login') }} @endif"
                    class="@if (auth()->check()) sendTip @endif ml-2"
                    data-post="{{ $post->id }}">
                    <img src="{{ asset('images/tip-icon.png') }}" alt="tip icon" class="w-6" />
                </a>
                <a href="@if (auth()->check()) javascript:void(0); @else {{ route('login') }} @endif"
                    class="ml-1 @if (auth()->check()) sendTip @endif text-stone-500 font-bold text-sm"
                    data-post="{{ $post->id }}">
                    @lang('general.tip')
                </a>
                <br/>
                <br/>
            </div>
        @endif

    </div>
</div>