@extends('account')

@section('seo_title')
    @lang('dashboard.accountSettings') -
@endsection

@section('account_section')
    <h2 class="text-2xl text-indigo-800 font-semibold flex items-center">
        <i class="fa-solid fa-cog mr-2"></i>
        <span>
            @lang('dashboard.accountSettings')
        </span>
    </h2>

    <div class="mt-5 px-3 py-5 rounded-lg shadowm-sm bg-white">
        <div class="flex flex-col items-center justify-center space-x-2">
            <h2 class="text-lg text-indigo-800 pb-1 font-bold ">
                {{ __('Your subscription plan is') }}
            </h2>
            <h2 class="inline-flex px-3 py-1 rounded-lg border border-indigo-100 bg-indigo-200 text-indigo-600">
                {{ auth()->user()->isPlatinum()? __('Platinum'): __('Free Plan') }}
            </h2>

        </div>

        <hr class="my-5" />

        <h2 class="text-lg text-indigo-800 pb-1 text-center font-bold">
            {{ __('Your plan limits are') }}
        </h2>

        @if (auth()->user()->isPlatinum())
            <div class="text-stone-600 font-semibold text-center text-lg">
                {{ __('As a PLATINUM user, sky is the limit!') }}<br />
                {{ __('Subscription will renew on') }}

                @if (!is_null(auth()->user()->subscription_expires))
                    <br />
                    <h2
                        class="inline-flex px-3 py-1 font-normal text-base rounded-lg border border-indigo-100 bg-indigo-200 text-indigo-600">
                        {{ auth()->user()->subscription_expires->format('jS F Y') }}
                    </h2>
                @else
                    <h2
                        class="inline-flex px-3 py-1 font-normal text-base rounded-lg border border-indigo-100 bg-indigo-200 text-indigo-600">
                        -/-
                    </h2>
                @endif
            </div>
        @else
            <ul role="list" class="mt-3 mb-2 space-y-1 text-left w-90 mx-auto">
                <x-feature-item :isAlt="true">
                    {{ __('Up to :freePostsLimit Feed Posts', ['freePostsLimit' => opt('free_posts_limit')]) }}
                </x-feature-item>
                <x-feature-item>{{ __('Up to :freeShopLimit Shop Products', ['freeShopLimit' => opt('free_shop_limit')]) }}
                </x-feature-item>
                <x-feature-item :isAlt="true">
                    {{ __('Max :freeDonationsLimit Coffees/Tips', ['freeDonationsLimit' => opt('free_tips_limit')]) }}
                </x-feature-item>
                <x-feature-item>
                    {{ __('Up to :paidSubscribersLimit Paid Subscribers', ['paidSubscribersLimit' => opt('free_subscribers_limit')]) }}
                </x-feature-item>
                <x-feature-item :isAlt="true">
                    {{ __('ADS on your profile pages and platform wide while you are logged in') }}</x-feature-item>
            </ul>

            <div class="mt-5 flex justify-center">
                <a href="{{ route('home') }}#platinum"
                    class="rounded-full px-5 py-2 font-bold text-indigo-600 border-2 border-indigo-600 hover:text-indigo-800 hover:border-indigo-800 hover:bg-indigo-200">{{ __('Select a Platinum Subscription') }}</a>
            </div>
        @endif

    </div>


    <div class="mt-5 px-3 py-5 rounded-lg shadowm-sm bg-white">
        <form method="POST" action="{{ route('storeMyPage') }}" enctype="multipart/form-data">
            @csrf
            <x-label>{{ __('Username') }}</x-label>
            <div
                class="flex items-center rounded-md shadow-sm border-2 border-indigo-200 outline-indigo-500 text-indigo-700 font-bold">
                <div class="bg-indigo-100 px-1 py-2 rounded-tl-md rounded-bl-md">
                    {{ route('home') }}/
                </div>
                <div class="flex-grow">
                    <input type="text" name="username"
                        class="text-lg lg:ml-1 bg-white border-none hover:border-none ring-0 order-transparent focus:border-transparent focus:ring-0 outline-none text-indigo-700 font-semibold"
                        value="{{ auth()->user()->profile->username }}" />
                </div>
            </div>
            <br>

            <x-label>{{ __('Category') }}</x-label>
            <x-select name="category" class="md:w-1/2 w-full">
                <option value="">@lang('dashboard.selectCategory')</option>
                @foreach ($all_categories as $c)
                    <option value="{{ $c->id }}" @if ($c->id == auth()->user()->profile->category_id) selected @endif>
                        {{ $c->category }}</option>
                @endforeach
            </x-select>
            <br><br>

            <x-label>{{ __('Profile About Me') }}</x-label>
            <x-textarea name="creating" cols="5" class="w-full">{{ auth()->user()->profile->creating }}</x-textarea>
            <br><br>

            <x-label>@lang('dashboard.profilePicture') (@lang('dashboard.minCover') 200x200)</x-label>
            <input type="file" name="profilePic" class="form-control" accept="image/*">
            <br /><br />

            <x-label>@lang('dashboard.coverPic') (@lang('dashboard.minCover') 1080x300)</x-label>
            <input type="file" name="coverPic" class="form-control" accept="image/*">
            <br /><br />

            <x-button>
                {{ __('Save Profile') }}
            </x-button>
        </form>
    </div>


    <div class="mt-5 px-3 py-5 rounded-lg shadowm-sm bg-white">
        <span class="text-lg text-indigo-800 pb-3 flex">@lang('profile.profileSettingsText')</span>
        <form method="POST" action="{{ route('saveAccountSettings') }}">
            @csrf

            <x-label>{{ __('Your Name') }}</x-label>
            <x-input type="text" name="name" class="w-full" value="{{ auth()->user()->name }}" />
            <br><br>

            <x-label>{{ __('Email Address') }}</x-label>
            <x-input type="email" name="email" class="w-full" value="{{ auth()->user()->email }}" />
            <br><br>




            <x-label>{{ __('Leave empty to keep current') }}</x-label>
            <x-input type="password" name="password" class="w-full" />
            <br><br>

            <x-label>{{ __('Leave empty to keep current') }}</x-label>
            <x-input type="password" name="password_confirmation" class="w-full" />
            <br><br>

            <x-button>
                {{ __('Save Details') }}
            </x-button>
        </form>
    </div>
@endsection
