@extends('welcome')

@section('seo_title')
    {{ __('Stripe')  }} -
@endsection

@section('content')
    <div class="container mt-10">
        <div class="bg-white rounded-lg p-3 max-w-md mx-auto shadow-sm mt-10">

            <div class="mt-5 text-center text-xl text-stone-600 font-semibold">
                <h5>
                    @lang('general.subscribeResult')
                </h5>
            </div>

           <div id="message" class="text-center mt-5 text-lg text-stone-600"></div>
           

        </div>
    </div>
@endsection

{{-- attention, this is dynamically appended using stack() and push() functions of BLADE --}}
@push('extraJS')
    <script src="https://js.stripe.com/v3/"></script>
    <script>
        // Initialize Stripe.js using your publishable key
        const stripe = Stripe('{{ opt("STRIPE_PUBLIC_KEY") }}');

        // Retrieve the "payment_intent_client_secret" query parameter appended to
        // your return_url by Stripe.js
        const clientSecret = new URLSearchParams(window.location.search).get(
            'payment_intent_client_secret'
        );

        // Retrieve the PaymentIntent
        stripe.retrievePaymentIntent(clientSecret).then(({
            paymentIntent
        }) => {
            const message = document.querySelector('#message')

            // [0]: https://stripe.com/docs/payments/payment-methods#payment-notification
            switch (paymentIntent.status) {
                case 'succeeded':
                    message.innerText = '{{ __("Payment Successfully received! Your subscription status will update shortly and your account will become PLATINUM.")  }}';
                    break;

                case 'processing':
                    message.innerText = '{{ __("Payment processing. We will update you when payment is received.") }}';
                    break;

                case 'requires_payment_method':
                    message.innerText = '{{ __("Payment failed. Please try another payment method.")  }}';
                    break;

                default:
                    message.innerText = '{{ __("Something went wrong with Stripe Payment Processor")  }}';
                    break;
            }
        });
    </script>
@endpush
