@extends('welcome')

@section('seo_title')
    {{  __('Stripe') }} -
@endsection

@section('content')
    <div class="container mt-10">
        <div class="bg-white rounded-lg p-3 max-w-md mx-auto shadow-sm mt-10">

            <div class="mt-5 text-center text-xl text-stone-600 font-semibold">
                <h5>
                    @lang('general.subscribeInfoPlatinum', [
                        'amount' => opt('payment-settings.currency_symbol') . $amount,
                        'period' => $plan,
                    ])
                </h5>
            </div>

            <form id="payment-form">
                <div id="payment-element">
                    <!-- Elements will create form elements here -->
                </div>
                <button id="submit">{{ __('Subscribe')  }}</button>
                <div id="error-message">
                    <!-- Display error message to your customers here -->
                </div>
            </form>

        </div>
    </div>
@endsection

{{-- attention, this is dynamically appended using stack() and push() functions of BLADE --}}
@push('extraJS')
    <script src="https://js.stripe.com/v3/"></script>
    <script>
        const stripe = Stripe('{{ opt('STRIPE_PUBLIC_KEY') }}');
        const options = {
            clientSecret: '{{ $clientSecret }}',
        };

        // Set up Stripe.js and Elements to use in checkout form, passing the client secret obtained in step 5
        const elements = stripe.elements(options);

        // Create and mount the Payment Element
        const paymentElement = elements.create('payment');
        paymentElement.mount('#payment-element');

        const form = document.getElementById('payment-form');

        form.addEventListener('submit', async (event) => {
            event.preventDefault();

            const {
                error
            } = await stripe.confirmPayment({
                //`Elements` instance that was used to create the Payment Element
                elements,
                confirmParams: {
                    return_url: "{{ route('saas.stripeSubscriptionResult') }}",
                }
            });

            if (error) {
                const messageContainer = document.querySelector('#error-message');
                messageContainer.textContent = error.message;
            } 
        });
    </script>
@endpush
