@extends('account')

@section('seo_title')
    @lang('dashboard.shop') -
@endsection

@section('account_section')
    <h2 class="text-2xl text-indigo-800 font-semibold flex items-center">
        <i class="fa-solid fa-shop mr-2"></i>
        @if (!request()->has('product_id'))
            @lang('shop.addProduct')
        @else
            @lang('shop.manageProduct')
        @endif
    </h2>

    @if (!auth()->user()->isPlatinum() && !request()->has('product_id'))
        <x-products-limit />
    @endif

    <div class="mt-5 px-5 py-8 rounded-md shadow-sm bg-white">
        <form method="POST" action="{{ route('shop.saveProduct') }}" enctype="multipart/form-data">
            @csrf

            @if (isset($product))
                <input type="hidden" name="product_id" value="{{ $product->id }}" />
            @endif

            <x-label>{{ __('Product Name*') }}</x-label>
            <x-input type="text" name="product_name" class="w-full"
                value="{{ $product->product_name ?? old('product_name') }}" />
            <br><br>

            <div class="lg:flex lg:flex-row items-center">

                <div>
                    <x-label>{{ __('Price*') }}<small class="pl-1 text-indigo-400 font-light">{{__('without currency')  }}</small>
                    </x-label>
                    <x-input type="number" name="price" class="w-full" value="{{ $product->price ?? old('price') }}" />
                </div>

                <div class="mt-5 lg:mt-0 ml-0 lg:ml-5">
            <x-label>{{ __('Stock') }}<small class="pl-1 text-indigo-400 font-light">{{ __('optional')  }}</small></x-label>
                    <x-input type="number" name="stock" class="w-full" step="1" min="0"
                        value="{{ $product->stock ?? old('stock') }}" />
                </div>
            </div>
            <br><br>

            <x-label>{{ __('Product Description') }}<small class="pl-1 text-indigo-400 font-light">{{ __('optional')  }}</small>
            </x-label>
            <x-textarea name="description" class="w-full">{{ $product->description ?? old('description') }}</x-textarea>
            <br><br>

            <x-label>{{ __('Product Photos*') }}<small class="pl-1 text-indigo-400 font-light">{{ __('min 300x300px') }}</small>
            </x-label>
            <div class="border-2 rounded p-2 border-indigo-200 bg-violet-50 mb-5">
                <div class="w-full h-auto relative mt-5">
                    <input id="filePond" type="file" name="files[]" accept="image/jpg,image/png,image/jpeg" multiple />
                </div>

            </div>
            
            <div x-data="{isDigital: '{{$product?->is_digital == 'yes' ? 'yes' : 'no'}}'}">
            <x-label>{{ __('v104.isDigital') }}
            </x-label>
            <x-select class="mb-5" name="isDigital" x-model="isDigital" x-on:change="$event.target.value=='yes' ? isDigital = 'yes' : isDigital = 'no';">
            <option value="no">@lang('v104.digitalNo')</option>
            <option value="yes">@lang('v104.digitalYes')</option>
            </x-select>

            <div x-show="isDigital == 'yes'" class="mb-5">
            <x-label>{{ __('v104.digitalFile') }}<small class="pl-1 text-indigo-400 font-light">{{ __('v104.zipExtension') }}</small>
            </x-label>
            <x-input type="file" name="zip_file" accept="application/zip" />
            </div>
            </div>

            @if (auth()->user()->canAddProducts())
                <x-button id="sbManageProduct">
                    {{ __('Save Product') }}
                </x-button>
            @elseif(!auth()->user()->canAddProducts() && request()->has('product_id'))
                <x-button id="sbManageProduct">
                    {{ __('Save Product') }}
                </x-button>
            @endif

        </form>
    </div>
@endsection


{{-- attention, this is dynamic and only needed on this page, uses laravel push/stack feature  --}}
@push('extraJS')
    <script>
        window.addEventListener("load", function() {

            let pond = window.pond;

            @if (isset($product) && !is_null($product) && $product->images()->count())
                pond.setOptions({
                    files: [
                        @foreach ($product->images as $image)
                            {
                                source: '{{ $image->id }}',
                                options: {
                                    type: 'local',
                                },
                            },
                        @endforeach
                    ]
                });
            @endif

        });

        // listen for events
        document.addEventListener('FilePond:addfilestart', (e) => {
            $("#sbManageProduct").attr('disabled', true);
            $("#sbManageProduct").hide();
        });

        document.addEventListener('FilePond:addfile', (e) => {
            $("#sbManageProduct").attr('disabled', false);
            $("#sbManageProduct").show();
        });

        document.addEventListener('FilePond:processfileprogress', (e) => {
            $("#sbManageProduct").attr('disabled', true);
            $("#sbManageProduct").hide();
        });

        document.addEventListener('FilePond:processfile', (e) => {
            $("#sbManageProduct").attr('disabled', false);
            $("#sbManageProduct").show();
        });
    </script>
@endpush
