@extends('account')

@section('seo_title')
    @lang('dashboard.shop') -
@endsection

@section('account_section')
    <h2 class="text-2xl text-indigo-800 font-semibold flex items-center">
        <i class="fa-solid fa-shop mr-2"></i>
        @lang('shop.manageOrder')
    </h2>

    @if(auth()->id() == $order->seller_id)
        <a href="{{route('shop.ordersReceived')}}" class="text-sm">&raquo; {{ __('Back to Orders') }}</a>
    @else
        <a href="{{route('shop.ordersPlaced')}}">&raquo; {{ __('Back to Orders') }}</a>
    @endif

    <div class="mt-5 px-5 py-8 rounded-md shadow-sm bg-white">
        <h2 class="text-stone-600 font-semibold text-lg">{{ __('Shipping Info') }}</h2>
        <div class="grid grid-cols-2 text-stone-600">
            <div class="mt-3">
               <span class="font-bold">{{ __('Full Name')  }} </span>
               <br/>
               {{ $order->shipping_details['fullname'] }}
            </div>

            <div class="mt-3">
                @if(auth()->id() == $order->seller_id)
                    <span class="font-bold">{{ __('Username')  }}</span>
                    <br/>
                    <a href="{{route('profile.show', ['username' => $order->buyer->profile->username])  }}" class="text-indigo-600">
                        {{ $order->buyer->profile->handle }}
                    </a>
               @else
                    <span class="font-bold">{{ __('Seller')  }}</span>
                    <br/>
                    <a href="{{route('profile.show', ['username' => $order->seller->profile->username])  }}" class="text-indigo-600">
                        {{ $order->seller->profile->handle }}
                    </a>
               @endif
            </div>

            <div class="mt-5">
                <span class="font-bold">{{ __('City')  }}</span>
                <br/>
                {{ $order->shipping_details['city'] }}
             </div>
 
             <div class="mt-5">
                <span class="font-bold">{{ __('State')  }}</span>
                <br/>
                {{ $order->shipping_details['state'] }}
             </div>

             <div class="mt-5">
                <span class="font-bold">{{ __('general.shippingCountry')  }}</span>
                <br/>
                {{ $order->shipping_details['country'] }}
             </div>
 
             <div class="mt-5">
                <span class="font-bold">{{ __('Postcode')  }}</span>
                <br/>
                {{ $order->shipping_details['postcode'] }}
             </div>

             <div class="mt-5">
                <span class="font-bold">{{ __('Phone No')  }}</span>
                <br/>
                {{ $order->shipping_details['phone'] }}
             </div>
        </div>

        <div class="mt-5">
            <span class="font-bold">{{ __('Address')  }}</span>
            <br/>
            {{ $order->shipping_details['address'] }}
        </div>
    </div>

    <div class="mt-5 px-5 py-8 rounded-md shadow-sm bg-white">
        <h2 class="text-stone-600 font-semibold text-lg">{{ __('Order Details')  }}
        
        <div class="flex mt-3 space-x-3">
            <div>
                <a href="{{ $order->product->slug }}" class="text-indigo-800 hover:text-indigo-700">
                    <img class="w-16 h-auto rounded-lg"
                        src="{{ Storage::disk(env('DEFAULT_STORAGE', 'public'))->url($order->product->images()->where('is_default', 'yes')->first()['image']) }}"
                        alt="" />
                </a>
            </div>
            <div class="flex-grow">
                <a href="{{$order->product->slug}}"
                    class="text-indigo-800 hover:text-indigo-600">
                    {{ $order->product->product_name }}
                </a> 
            </div>
        </div>

        <div class="grid grid-cols-2 mt-3 text-stone-600">
            <div class="mt-3">
               <span class="font-bold">{{ __('Product Price')  }} </span>
               <br/>
                {{ opt('payment-settings.currency_symbol') . $order->product_price  }}
            </div>

            <div class="mt-3">
                <span class="font-bold">{{ __('Shipping Price')  }}</span>
               <br/>
                {{ opt('payment-settings.currency_symbol') . $order->shipping_price  }}
            </div> 
        </div>

        <div class="mt-3">
            <span class="font-bold">{{ __('Order Total')  }}</span>
            <br/>
            {{ opt('payment-settings.currency_symbol') . $order->order_total  }}
        </div>

        @if(auth()->id() == $order->seller_id)
            <hr class="my-3"/>
            <form method="POST" action="{{route('shop.updateOrderStatus', ['order' => $order])}}">
                @csrf
                <span class="flex font-bold">{{ __('Order Status')  }}</span>
                <x-input name="order_status" value="{{ $order->order_status }}" />
                
                <span class="flex font-bold mt-2">
                    {{ __('Order Comments')  }}
                </span>
                <span class="flex text-sm"><em>{{ __('Visible to customer in order details page')  }}</em></span>
                <x-textarea name="order_comments" cols="5" class="w-full">{{$order->order_comments}}</x-textarea>
                
                <x-button class="mt-3">{{__('Update Status') }}</x-button>
            </form>
        @else
        <hr class="my-5">
            <div class="mt-3">
                <span class="font-bold">{{ __('Order Status')  }}</span>
                <br/>
                {{ $order->order_status  }}
            </div>
            @if(!empty($order->order_comments))
            <div class="mt-3">
                <span class="font-bold">{{ __('Order Comments')  }}</span>
                <br/>
                {{--  attention, using mews purifier clean() method to allow newlines to show --}}
                {!! clean(nl2br($order->order_comments)) !!}
            </div>
            @endif
        @endif

    </div>
@endsection