@extends('account')

@section('seo_title')
    @lang('dashboard.shop') -
@endsection

@section('account_section')
    <h2 class="text-2xl text-indigo-800 font-semibold flex items-center">
        <i class="fa-solid fa-shop mr-2"></i>
        @lang('shop.myProducts')
    </h2>

    @if(!auth()->user()->isPlatinum())
        <x-products-limit />
    @endif

    @if($products->count())
    <table class="mt-5 bg-white shadow-sm rounded-lg px-3 py-5 border-collapse table-auto w-full">
        <thead class="bg-indigo-200 rounded-lg">
            <tr>
                <th class="border-b font-medium py-4 px-2 text-indigo-700 text-left rounded-tl-lg">
                    {{ __('Thumbnail') }}
                </th>
                <th class="border-b font-medium py-4 px-2 text-indigo-700 text-left">
                    {{ __('Product') }}
                </th>
                <th class="border-b font-medium py-4 px-2 text-indigo-700 text-left">
                    {{ __('Price') }}
                </th>
                <th class="border-b font-medium py-4 px-2 text-indigo-700 text-left rounded-tr-lg">
                    {{ __('Stock') }}
                </th>
            </tr>
        </thead>
        <tbody>
            @foreach ($products as $p)
                <tr>
                    <td class="py-4 px-2">
                        <a href="{{ $p->slug }}" class="text-indigo-800 hover:text-indigo-700">
                            <img class="w-16 h-auto rounded-lg"
                                src="{{ Storage::disk(env('DEFAULT_STORAGE', 'public'))->url($p->images()->where('is_default', 'yes')->first()['image']) }}"
                                alt="" />
                        </a>
                    </td>
                    <td class="py-4 px-2">
                        <a href="{{ route('shop.addProduct') }}?product_id={{ $p->id }}"
                            class="text-indigo-800 hover:text-indigo-600">{{ $p->product_name }}</a>
                    </td>
                    <td class="text-stone-500 px-2 py-4 text-sm font-bold">
                        {{ opt('payment-settings.currency_symbol') . $p->price }}
                    </td>
                    <td class="text-stone-700 px-2 py-4">
                        <span class="p-1 text-sm rounded-lg bg-stone-100">
                            {{ $p->stock ?? '--' }}
                        </span>
                    </td>
                </tr>
            @endforeach
        </tbody>
    </table>
    @else
        <div class="p-3 rounded-lg bg-white mt-3">
            @lang('general.noProducts') - <a href="{{ route('shop.addProduct') }}"
            class="text-indigo-800 hover:text-indigo-600 @if (isset($active) && $active == 'shop.add-product') font-bold @endif">
            {{ __('Add Product')  }}
        </a>
        </div>
    @endif
    </div>
@endsection
